"""__init__.py"""

import sys
from typing import TYPE_CHECKING

from lazy_imports import LazyImporter


if TYPE_CHECKING:
    from ._6298 import AbstractAssemblyDynamicAnalysis
    from ._6299 import AbstractShaftDynamicAnalysis
    from ._6300 import AbstractShaftOrHousingDynamicAnalysis
    from ._6301 import AbstractShaftToMountableComponentConnectionDynamicAnalysis
    from ._6302 import AGMAGleasonConicalGearDynamicAnalysis
    from ._6303 import AGMAGleasonConicalGearMeshDynamicAnalysis
    from ._6304 import AGMAGleasonConicalGearSetDynamicAnalysis
    from ._6305 import AssemblyDynamicAnalysis
    from ._6306 import BearingDynamicAnalysis
    from ._6307 import BeltConnectionDynamicAnalysis
    from ._6308 import BeltDriveDynamicAnalysis
    from ._6309 import BevelDifferentialGearDynamicAnalysis
    from ._6310 import BevelDifferentialGearMeshDynamicAnalysis
    from ._6311 import BevelDifferentialGearSetDynamicAnalysis
    from ._6312 import BevelDifferentialPlanetGearDynamicAnalysis
    from ._6313 import BevelDifferentialSunGearDynamicAnalysis
    from ._6314 import BevelGearDynamicAnalysis
    from ._6315 import BevelGearMeshDynamicAnalysis
    from ._6316 import BevelGearSetDynamicAnalysis
    from ._6317 import BoltDynamicAnalysis
    from ._6318 import BoltedJointDynamicAnalysis
    from ._6319 import ClutchConnectionDynamicAnalysis
    from ._6320 import ClutchDynamicAnalysis
    from ._6321 import ClutchHalfDynamicAnalysis
    from ._6322 import CoaxialConnectionDynamicAnalysis
    from ._6323 import ComponentDynamicAnalysis
    from ._6324 import ConceptCouplingConnectionDynamicAnalysis
    from ._6325 import ConceptCouplingDynamicAnalysis
    from ._6326 import ConceptCouplingHalfDynamicAnalysis
    from ._6327 import ConceptGearDynamicAnalysis
    from ._6328 import ConceptGearMeshDynamicAnalysis
    from ._6329 import ConceptGearSetDynamicAnalysis
    from ._6330 import ConicalGearDynamicAnalysis
    from ._6331 import ConicalGearMeshDynamicAnalysis
    from ._6332 import ConicalGearSetDynamicAnalysis
    from ._6333 import ConnectionDynamicAnalysis
    from ._6334 import ConnectorDynamicAnalysis
    from ._6335 import CouplingConnectionDynamicAnalysis
    from ._6336 import CouplingDynamicAnalysis
    from ._6337 import CouplingHalfDynamicAnalysis
    from ._6338 import CVTBeltConnectionDynamicAnalysis
    from ._6339 import CVTDynamicAnalysis
    from ._6340 import CVTPulleyDynamicAnalysis
    from ._6341 import CycloidalAssemblyDynamicAnalysis
    from ._6342 import CycloidalDiscCentralBearingConnectionDynamicAnalysis
    from ._6343 import CycloidalDiscDynamicAnalysis
    from ._6344 import CycloidalDiscPlanetaryBearingConnectionDynamicAnalysis
    from ._6345 import CylindricalGearDynamicAnalysis
    from ._6346 import CylindricalGearMeshDynamicAnalysis
    from ._6347 import CylindricalGearSetDynamicAnalysis
    from ._6348 import CylindricalPlanetGearDynamicAnalysis
    from ._6349 import DatumDynamicAnalysis
    from ._6350 import DynamicAnalysis
    from ._6351 import DynamicAnalysisDrawStyle
    from ._6352 import ExternalCADModelDynamicAnalysis
    from ._6353 import FaceGearDynamicAnalysis
    from ._6354 import FaceGearMeshDynamicAnalysis
    from ._6355 import FaceGearSetDynamicAnalysis
    from ._6356 import FEPartDynamicAnalysis
    from ._6357 import FlexiblePinAssemblyDynamicAnalysis
    from ._6358 import GearDynamicAnalysis
    from ._6359 import GearMeshDynamicAnalysis
    from ._6360 import GearSetDynamicAnalysis
    from ._6361 import GuideDxfModelDynamicAnalysis
    from ._6362 import HypoidGearDynamicAnalysis
    from ._6363 import HypoidGearMeshDynamicAnalysis
    from ._6364 import HypoidGearSetDynamicAnalysis
    from ._6365 import InterMountableComponentConnectionDynamicAnalysis
    from ._6366 import KlingelnbergCycloPalloidConicalGearDynamicAnalysis
    from ._6367 import KlingelnbergCycloPalloidConicalGearMeshDynamicAnalysis
    from ._6368 import KlingelnbergCycloPalloidConicalGearSetDynamicAnalysis
    from ._6369 import KlingelnbergCycloPalloidHypoidGearDynamicAnalysis
    from ._6370 import KlingelnbergCycloPalloidHypoidGearMeshDynamicAnalysis
    from ._6371 import KlingelnbergCycloPalloidHypoidGearSetDynamicAnalysis
    from ._6372 import KlingelnbergCycloPalloidSpiralBevelGearDynamicAnalysis
    from ._6373 import KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis
    from ._6374 import KlingelnbergCycloPalloidSpiralBevelGearSetDynamicAnalysis
    from ._6375 import MassDiscDynamicAnalysis
    from ._6376 import MeasurementComponentDynamicAnalysis
    from ._6377 import MountableComponentDynamicAnalysis
    from ._6378 import OilSealDynamicAnalysis
    from ._6379 import PartDynamicAnalysis
    from ._6380 import PartToPartShearCouplingConnectionDynamicAnalysis
    from ._6381 import PartToPartShearCouplingDynamicAnalysis
    from ._6382 import PartToPartShearCouplingHalfDynamicAnalysis
    from ._6383 import PlanetaryConnectionDynamicAnalysis
    from ._6384 import PlanetaryGearSetDynamicAnalysis
    from ._6385 import PlanetCarrierDynamicAnalysis
    from ._6386 import PointLoadDynamicAnalysis
    from ._6387 import PowerLoadDynamicAnalysis
    from ._6388 import PulleyDynamicAnalysis
    from ._6389 import RingPinsDynamicAnalysis
    from ._6390 import RingPinsToDiscConnectionDynamicAnalysis
    from ._6391 import RollingRingAssemblyDynamicAnalysis
    from ._6392 import RollingRingConnectionDynamicAnalysis
    from ._6393 import RollingRingDynamicAnalysis
    from ._6394 import RootAssemblyDynamicAnalysis
    from ._6395 import ShaftDynamicAnalysis
    from ._6396 import ShaftHubConnectionDynamicAnalysis
    from ._6397 import ShaftToMountableComponentConnectionDynamicAnalysis
    from ._6398 import SpecialisedAssemblyDynamicAnalysis
    from ._6399 import SpiralBevelGearDynamicAnalysis
    from ._6400 import SpiralBevelGearMeshDynamicAnalysis
    from ._6401 import SpiralBevelGearSetDynamicAnalysis
    from ._6402 import SpringDamperConnectionDynamicAnalysis
    from ._6403 import SpringDamperDynamicAnalysis
    from ._6404 import SpringDamperHalfDynamicAnalysis
    from ._6405 import StraightBevelDiffGearDynamicAnalysis
    from ._6406 import StraightBevelDiffGearMeshDynamicAnalysis
    from ._6407 import StraightBevelDiffGearSetDynamicAnalysis
    from ._6408 import StraightBevelGearDynamicAnalysis
    from ._6409 import StraightBevelGearMeshDynamicAnalysis
    from ._6410 import StraightBevelGearSetDynamicAnalysis
    from ._6411 import StraightBevelPlanetGearDynamicAnalysis
    from ._6412 import StraightBevelSunGearDynamicAnalysis
    from ._6413 import SynchroniserDynamicAnalysis
    from ._6414 import SynchroniserHalfDynamicAnalysis
    from ._6415 import SynchroniserPartDynamicAnalysis
    from ._6416 import SynchroniserSleeveDynamicAnalysis
    from ._6417 import TorqueConverterConnectionDynamicAnalysis
    from ._6418 import TorqueConverterDynamicAnalysis
    from ._6419 import TorqueConverterPumpDynamicAnalysis
    from ._6420 import TorqueConverterTurbineDynamicAnalysis
    from ._6421 import UnbalancedMassDynamicAnalysis
    from ._6422 import VirtualComponentDynamicAnalysis
    from ._6423 import WormGearDynamicAnalysis
    from ._6424 import WormGearMeshDynamicAnalysis
    from ._6425 import WormGearSetDynamicAnalysis
    from ._6426 import ZerolBevelGearDynamicAnalysis
    from ._6427 import ZerolBevelGearMeshDynamicAnalysis
    from ._6428 import ZerolBevelGearSetDynamicAnalysis
else:
    import_structure = {
        "_6298": ["AbstractAssemblyDynamicAnalysis"],
        "_6299": ["AbstractShaftDynamicAnalysis"],
        "_6300": ["AbstractShaftOrHousingDynamicAnalysis"],
        "_6301": ["AbstractShaftToMountableComponentConnectionDynamicAnalysis"],
        "_6302": ["AGMAGleasonConicalGearDynamicAnalysis"],
        "_6303": ["AGMAGleasonConicalGearMeshDynamicAnalysis"],
        "_6304": ["AGMAGleasonConicalGearSetDynamicAnalysis"],
        "_6305": ["AssemblyDynamicAnalysis"],
        "_6306": ["BearingDynamicAnalysis"],
        "_6307": ["BeltConnectionDynamicAnalysis"],
        "_6308": ["BeltDriveDynamicAnalysis"],
        "_6309": ["BevelDifferentialGearDynamicAnalysis"],
        "_6310": ["BevelDifferentialGearMeshDynamicAnalysis"],
        "_6311": ["BevelDifferentialGearSetDynamicAnalysis"],
        "_6312": ["BevelDifferentialPlanetGearDynamicAnalysis"],
        "_6313": ["BevelDifferentialSunGearDynamicAnalysis"],
        "_6314": ["BevelGearDynamicAnalysis"],
        "_6315": ["BevelGearMeshDynamicAnalysis"],
        "_6316": ["BevelGearSetDynamicAnalysis"],
        "_6317": ["BoltDynamicAnalysis"],
        "_6318": ["BoltedJointDynamicAnalysis"],
        "_6319": ["ClutchConnectionDynamicAnalysis"],
        "_6320": ["ClutchDynamicAnalysis"],
        "_6321": ["ClutchHalfDynamicAnalysis"],
        "_6322": ["CoaxialConnectionDynamicAnalysis"],
        "_6323": ["ComponentDynamicAnalysis"],
        "_6324": ["ConceptCouplingConnectionDynamicAnalysis"],
        "_6325": ["ConceptCouplingDynamicAnalysis"],
        "_6326": ["ConceptCouplingHalfDynamicAnalysis"],
        "_6327": ["ConceptGearDynamicAnalysis"],
        "_6328": ["ConceptGearMeshDynamicAnalysis"],
        "_6329": ["ConceptGearSetDynamicAnalysis"],
        "_6330": ["ConicalGearDynamicAnalysis"],
        "_6331": ["ConicalGearMeshDynamicAnalysis"],
        "_6332": ["ConicalGearSetDynamicAnalysis"],
        "_6333": ["ConnectionDynamicAnalysis"],
        "_6334": ["ConnectorDynamicAnalysis"],
        "_6335": ["CouplingConnectionDynamicAnalysis"],
        "_6336": ["CouplingDynamicAnalysis"],
        "_6337": ["CouplingHalfDynamicAnalysis"],
        "_6338": ["CVTBeltConnectionDynamicAnalysis"],
        "_6339": ["CVTDynamicAnalysis"],
        "_6340": ["CVTPulleyDynamicAnalysis"],
        "_6341": ["CycloidalAssemblyDynamicAnalysis"],
        "_6342": ["CycloidalDiscCentralBearingConnectionDynamicAnalysis"],
        "_6343": ["CycloidalDiscDynamicAnalysis"],
        "_6344": ["CycloidalDiscPlanetaryBearingConnectionDynamicAnalysis"],
        "_6345": ["CylindricalGearDynamicAnalysis"],
        "_6346": ["CylindricalGearMeshDynamicAnalysis"],
        "_6347": ["CylindricalGearSetDynamicAnalysis"],
        "_6348": ["CylindricalPlanetGearDynamicAnalysis"],
        "_6349": ["DatumDynamicAnalysis"],
        "_6350": ["DynamicAnalysis"],
        "_6351": ["DynamicAnalysisDrawStyle"],
        "_6352": ["ExternalCADModelDynamicAnalysis"],
        "_6353": ["FaceGearDynamicAnalysis"],
        "_6354": ["FaceGearMeshDynamicAnalysis"],
        "_6355": ["FaceGearSetDynamicAnalysis"],
        "_6356": ["FEPartDynamicAnalysis"],
        "_6357": ["FlexiblePinAssemblyDynamicAnalysis"],
        "_6358": ["GearDynamicAnalysis"],
        "_6359": ["GearMeshDynamicAnalysis"],
        "_6360": ["GearSetDynamicAnalysis"],
        "_6361": ["GuideDxfModelDynamicAnalysis"],
        "_6362": ["HypoidGearDynamicAnalysis"],
        "_6363": ["HypoidGearMeshDynamicAnalysis"],
        "_6364": ["HypoidGearSetDynamicAnalysis"],
        "_6365": ["InterMountableComponentConnectionDynamicAnalysis"],
        "_6366": ["KlingelnbergCycloPalloidConicalGearDynamicAnalysis"],
        "_6367": ["KlingelnbergCycloPalloidConicalGearMeshDynamicAnalysis"],
        "_6368": ["KlingelnbergCycloPalloidConicalGearSetDynamicAnalysis"],
        "_6369": ["KlingelnbergCycloPalloidHypoidGearDynamicAnalysis"],
        "_6370": ["KlingelnbergCycloPalloidHypoidGearMeshDynamicAnalysis"],
        "_6371": ["KlingelnbergCycloPalloidHypoidGearSetDynamicAnalysis"],
        "_6372": ["KlingelnbergCycloPalloidSpiralBevelGearDynamicAnalysis"],
        "_6373": ["KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis"],
        "_6374": ["KlingelnbergCycloPalloidSpiralBevelGearSetDynamicAnalysis"],
        "_6375": ["MassDiscDynamicAnalysis"],
        "_6376": ["MeasurementComponentDynamicAnalysis"],
        "_6377": ["MountableComponentDynamicAnalysis"],
        "_6378": ["OilSealDynamicAnalysis"],
        "_6379": ["PartDynamicAnalysis"],
        "_6380": ["PartToPartShearCouplingConnectionDynamicAnalysis"],
        "_6381": ["PartToPartShearCouplingDynamicAnalysis"],
        "_6382": ["PartToPartShearCouplingHalfDynamicAnalysis"],
        "_6383": ["PlanetaryConnectionDynamicAnalysis"],
        "_6384": ["PlanetaryGearSetDynamicAnalysis"],
        "_6385": ["PlanetCarrierDynamicAnalysis"],
        "_6386": ["PointLoadDynamicAnalysis"],
        "_6387": ["PowerLoadDynamicAnalysis"],
        "_6388": ["PulleyDynamicAnalysis"],
        "_6389": ["RingPinsDynamicAnalysis"],
        "_6390": ["RingPinsToDiscConnectionDynamicAnalysis"],
        "_6391": ["RollingRingAssemblyDynamicAnalysis"],
        "_6392": ["RollingRingConnectionDynamicAnalysis"],
        "_6393": ["RollingRingDynamicAnalysis"],
        "_6394": ["RootAssemblyDynamicAnalysis"],
        "_6395": ["ShaftDynamicAnalysis"],
        "_6396": ["ShaftHubConnectionDynamicAnalysis"],
        "_6397": ["ShaftToMountableComponentConnectionDynamicAnalysis"],
        "_6398": ["SpecialisedAssemblyDynamicAnalysis"],
        "_6399": ["SpiralBevelGearDynamicAnalysis"],
        "_6400": ["SpiralBevelGearMeshDynamicAnalysis"],
        "_6401": ["SpiralBevelGearSetDynamicAnalysis"],
        "_6402": ["SpringDamperConnectionDynamicAnalysis"],
        "_6403": ["SpringDamperDynamicAnalysis"],
        "_6404": ["SpringDamperHalfDynamicAnalysis"],
        "_6405": ["StraightBevelDiffGearDynamicAnalysis"],
        "_6406": ["StraightBevelDiffGearMeshDynamicAnalysis"],
        "_6407": ["StraightBevelDiffGearSetDynamicAnalysis"],
        "_6408": ["StraightBevelGearDynamicAnalysis"],
        "_6409": ["StraightBevelGearMeshDynamicAnalysis"],
        "_6410": ["StraightBevelGearSetDynamicAnalysis"],
        "_6411": ["StraightBevelPlanetGearDynamicAnalysis"],
        "_6412": ["StraightBevelSunGearDynamicAnalysis"],
        "_6413": ["SynchroniserDynamicAnalysis"],
        "_6414": ["SynchroniserHalfDynamicAnalysis"],
        "_6415": ["SynchroniserPartDynamicAnalysis"],
        "_6416": ["SynchroniserSleeveDynamicAnalysis"],
        "_6417": ["TorqueConverterConnectionDynamicAnalysis"],
        "_6418": ["TorqueConverterDynamicAnalysis"],
        "_6419": ["TorqueConverterPumpDynamicAnalysis"],
        "_6420": ["TorqueConverterTurbineDynamicAnalysis"],
        "_6421": ["UnbalancedMassDynamicAnalysis"],
        "_6422": ["VirtualComponentDynamicAnalysis"],
        "_6423": ["WormGearDynamicAnalysis"],
        "_6424": ["WormGearMeshDynamicAnalysis"],
        "_6425": ["WormGearSetDynamicAnalysis"],
        "_6426": ["ZerolBevelGearDynamicAnalysis"],
        "_6427": ["ZerolBevelGearMeshDynamicAnalysis"],
        "_6428": ["ZerolBevelGearSetDynamicAnalysis"],
    }

    sys.modules[__name__] = LazyImporter(
        __name__,
        globals()["__file__"],
        import_structure,
    )

__all__ = (
    "AbstractAssemblyDynamicAnalysis",
    "AbstractShaftDynamicAnalysis",
    "AbstractShaftOrHousingDynamicAnalysis",
    "AbstractShaftToMountableComponentConnectionDynamicAnalysis",
    "AGMAGleasonConicalGearDynamicAnalysis",
    "AGMAGleasonConicalGearMeshDynamicAnalysis",
    "AGMAGleasonConicalGearSetDynamicAnalysis",
    "AssemblyDynamicAnalysis",
    "BearingDynamicAnalysis",
    "BeltConnectionDynamicAnalysis",
    "BeltDriveDynamicAnalysis",
    "BevelDifferentialGearDynamicAnalysis",
    "BevelDifferentialGearMeshDynamicAnalysis",
    "BevelDifferentialGearSetDynamicAnalysis",
    "BevelDifferentialPlanetGearDynamicAnalysis",
    "BevelDifferentialSunGearDynamicAnalysis",
    "BevelGearDynamicAnalysis",
    "BevelGearMeshDynamicAnalysis",
    "BevelGearSetDynamicAnalysis",
    "BoltDynamicAnalysis",
    "BoltedJointDynamicAnalysis",
    "ClutchConnectionDynamicAnalysis",
    "ClutchDynamicAnalysis",
    "ClutchHalfDynamicAnalysis",
    "CoaxialConnectionDynamicAnalysis",
    "ComponentDynamicAnalysis",
    "ConceptCouplingConnectionDynamicAnalysis",
    "ConceptCouplingDynamicAnalysis",
    "ConceptCouplingHalfDynamicAnalysis",
    "ConceptGearDynamicAnalysis",
    "ConceptGearMeshDynamicAnalysis",
    "ConceptGearSetDynamicAnalysis",
    "ConicalGearDynamicAnalysis",
    "ConicalGearMeshDynamicAnalysis",
    "ConicalGearSetDynamicAnalysis",
    "ConnectionDynamicAnalysis",
    "ConnectorDynamicAnalysis",
    "CouplingConnectionDynamicAnalysis",
    "CouplingDynamicAnalysis",
    "CouplingHalfDynamicAnalysis",
    "CVTBeltConnectionDynamicAnalysis",
    "CVTDynamicAnalysis",
    "CVTPulleyDynamicAnalysis",
    "CycloidalAssemblyDynamicAnalysis",
    "CycloidalDiscCentralBearingConnectionDynamicAnalysis",
    "CycloidalDiscDynamicAnalysis",
    "CycloidalDiscPlanetaryBearingConnectionDynamicAnalysis",
    "CylindricalGearDynamicAnalysis",
    "CylindricalGearMeshDynamicAnalysis",
    "CylindricalGearSetDynamicAnalysis",
    "CylindricalPlanetGearDynamicAnalysis",
    "DatumDynamicAnalysis",
    "DynamicAnalysis",
    "DynamicAnalysisDrawStyle",
    "ExternalCADModelDynamicAnalysis",
    "FaceGearDynamicAnalysis",
    "FaceGearMeshDynamicAnalysis",
    "FaceGearSetDynamicAnalysis",
    "FEPartDynamicAnalysis",
    "FlexiblePinAssemblyDynamicAnalysis",
    "GearDynamicAnalysis",
    "GearMeshDynamicAnalysis",
    "GearSetDynamicAnalysis",
    "GuideDxfModelDynamicAnalysis",
    "HypoidGearDynamicAnalysis",
    "HypoidGearMeshDynamicAnalysis",
    "HypoidGearSetDynamicAnalysis",
    "InterMountableComponentConnectionDynamicAnalysis",
    "KlingelnbergCycloPalloidConicalGearDynamicAnalysis",
    "KlingelnbergCycloPalloidConicalGearMeshDynamicAnalysis",
    "KlingelnbergCycloPalloidConicalGearSetDynamicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearDynamicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearMeshDynamicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearSetDynamicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearDynamicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearSetDynamicAnalysis",
    "MassDiscDynamicAnalysis",
    "MeasurementComponentDynamicAnalysis",
    "MountableComponentDynamicAnalysis",
    "OilSealDynamicAnalysis",
    "PartDynamicAnalysis",
    "PartToPartShearCouplingConnectionDynamicAnalysis",
    "PartToPartShearCouplingDynamicAnalysis",
    "PartToPartShearCouplingHalfDynamicAnalysis",
    "PlanetaryConnectionDynamicAnalysis",
    "PlanetaryGearSetDynamicAnalysis",
    "PlanetCarrierDynamicAnalysis",
    "PointLoadDynamicAnalysis",
    "PowerLoadDynamicAnalysis",
    "PulleyDynamicAnalysis",
    "RingPinsDynamicAnalysis",
    "RingPinsToDiscConnectionDynamicAnalysis",
    "RollingRingAssemblyDynamicAnalysis",
    "RollingRingConnectionDynamicAnalysis",
    "RollingRingDynamicAnalysis",
    "RootAssemblyDynamicAnalysis",
    "ShaftDynamicAnalysis",
    "ShaftHubConnectionDynamicAnalysis",
    "ShaftToMountableComponentConnectionDynamicAnalysis",
    "SpecialisedAssemblyDynamicAnalysis",
    "SpiralBevelGearDynamicAnalysis",
    "SpiralBevelGearMeshDynamicAnalysis",
    "SpiralBevelGearSetDynamicAnalysis",
    "SpringDamperConnectionDynamicAnalysis",
    "SpringDamperDynamicAnalysis",
    "SpringDamperHalfDynamicAnalysis",
    "StraightBevelDiffGearDynamicAnalysis",
    "StraightBevelDiffGearMeshDynamicAnalysis",
    "StraightBevelDiffGearSetDynamicAnalysis",
    "StraightBevelGearDynamicAnalysis",
    "StraightBevelGearMeshDynamicAnalysis",
    "StraightBevelGearSetDynamicAnalysis",
    "StraightBevelPlanetGearDynamicAnalysis",
    "StraightBevelSunGearDynamicAnalysis",
    "SynchroniserDynamicAnalysis",
    "SynchroniserHalfDynamicAnalysis",
    "SynchroniserPartDynamicAnalysis",
    "SynchroniserSleeveDynamicAnalysis",
    "TorqueConverterConnectionDynamicAnalysis",
    "TorqueConverterDynamicAnalysis",
    "TorqueConverterPumpDynamicAnalysis",
    "TorqueConverterTurbineDynamicAnalysis",
    "UnbalancedMassDynamicAnalysis",
    "VirtualComponentDynamicAnalysis",
    "WormGearDynamicAnalysis",
    "WormGearMeshDynamicAnalysis",
    "WormGearSetDynamicAnalysis",
    "ZerolBevelGearDynamicAnalysis",
    "ZerolBevelGearMeshDynamicAnalysis",
    "ZerolBevelGearSetDynamicAnalysis",
)



"""AssemblyAdvancedTimeSteppingAnalysisForModulation"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar, List

from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation import (
    _7027,
)
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_ASSEMBLY_ADVANCED_TIME_STEPPING_ANALYSIS_FOR_MODULATION = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.AdvancedTimeSteppingAnalysesForModulation",
    "AssemblyAdvancedTimeSteppingAnalysisForModulation",
)

if TYPE_CHECKING:
    from mastapy.system_model.part_model import _2453
    from mastapy.system_model.analyses_and_results.static_loads import _6840
    from mastapy.system_model.analyses_and_results.system_deflections import _2713
    from mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation import (
        _7040,
        _7042,
        _7045,
        _7052,
        _7051,
        _7072,
        _7053,
        _7058,
        _7063,
        _7075,
        _7076,
        _7081,
        _7088,
        _7087,
        _7089,
        _7097,
        _7104,
        _7107,
        _7108,
        _7109,
        _7111,
        _7113,
        _7118,
        _7119,
        _7120,
        _7122,
        _7125,
        _7129,
        _7128,
        _7134,
        _7135,
        _7140,
        _7143,
        _7146,
        _7150,
        _7154,
        _7158,
        _7161,
        _7127,
        _7112,
    )
    from mastapy.system_model.analyses_and_results.analysis_cases import _7569, _7566
    from mastapy.system_model.analyses_and_results import _2678, _2674, _2672


__docformat__ = "restructuredtext en"
__all__ = ("AssemblyAdvancedTimeSteppingAnalysisForModulation",)


Self = TypeVar("Self", bound="AssemblyAdvancedTimeSteppingAnalysisForModulation")


class AssemblyAdvancedTimeSteppingAnalysisForModulation(
    _7027.AbstractAssemblyAdvancedTimeSteppingAnalysisForModulation
):
    """AssemblyAdvancedTimeSteppingAnalysisForModulation

    This is a mastapy class.
    """

    TYPE = _ASSEMBLY_ADVANCED_TIME_STEPPING_ANALYSIS_FOR_MODULATION
    _CastSelf = TypeVar(
        "_CastSelf", bound="_Cast_AssemblyAdvancedTimeSteppingAnalysisForModulation"
    )

    class _Cast_AssemblyAdvancedTimeSteppingAnalysisForModulation:
        """Special nested class for casting AssemblyAdvancedTimeSteppingAnalysisForModulation to subclasses."""

        def __init__(
            self: "AssemblyAdvancedTimeSteppingAnalysisForModulation._Cast_AssemblyAdvancedTimeSteppingAnalysisForModulation",
            parent: "AssemblyAdvancedTimeSteppingAnalysisForModulation",
        ):
            self._parent = parent

        @property
        def abstract_assembly_advanced_time_stepping_analysis_for_modulation(
            self: "AssemblyAdvancedTimeSteppingAnalysisForModulation._Cast_AssemblyAdvancedTimeSteppingAnalysisForModulation",
        ) -> "_7027.AbstractAssemblyAdvancedTimeSteppingAnalysisForModulation":
            return self._parent._cast(
                _7027.AbstractAssemblyAdvancedTimeSteppingAnalysisForModulation
            )

        @property
        def part_advanced_time_stepping_analysis_for_modulation(
            self: "AssemblyAdvancedTimeSteppingAnalysisForModulation._Cast_AssemblyAdvancedTimeSteppingAnalysisForModulation",
        ) -> "_7112.PartAdvancedTimeSteppingAnalysisForModulation":
            from mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation import (
                _7112,
            )

            return self._parent._cast(
                _7112.PartAdvancedTimeSteppingAnalysisForModulation
            )

        @property
        def part_static_load_analysis_case(
            self: "AssemblyAdvancedTimeSteppingAnalysisForModulation._Cast_AssemblyAdvancedTimeSteppingAnalysisForModulation",
        ) -> "_7569.PartStaticLoadAnalysisCase":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7569

            return self._parent._cast(_7569.PartStaticLoadAnalysisCase)

        @property
        def part_analysis_case(
            self: "AssemblyAdvancedTimeSteppingAnalysisForModulation._Cast_AssemblyAdvancedTimeSteppingAnalysisForModulation",
        ) -> "_7566.PartAnalysisCase":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7566

            return self._parent._cast(_7566.PartAnalysisCase)

        @property
        def part_analysis(
            self: "AssemblyAdvancedTimeSteppingAnalysisForModulation._Cast_AssemblyAdvancedTimeSteppingAnalysisForModulation",
        ) -> "_2678.PartAnalysis":
            from mastapy.system_model.analyses_and_results import _2678

            return self._parent._cast(_2678.PartAnalysis)

        @property
        def design_entity_single_context_analysis(
            self: "AssemblyAdvancedTimeSteppingAnalysisForModulation._Cast_AssemblyAdvancedTimeSteppingAnalysisForModulation",
        ) -> "_2674.DesignEntitySingleContextAnalysis":
            from mastapy.system_model.analyses_and_results import _2674

            return self._parent._cast(_2674.DesignEntitySingleContextAnalysis)

        @property
        def design_entity_analysis(
            self: "AssemblyAdvancedTimeSteppingAnalysisForModulation._Cast_AssemblyAdvancedTimeSteppingAnalysisForModulation",
        ) -> "_2672.DesignEntityAnalysis":
            from mastapy.system_model.analyses_and_results import _2672

            return self._parent._cast(_2672.DesignEntityAnalysis)

        @property
        def root_assembly_advanced_time_stepping_analysis_for_modulation(
            self: "AssemblyAdvancedTimeSteppingAnalysisForModulation._Cast_AssemblyAdvancedTimeSteppingAnalysisForModulation",
        ) -> "_7127.RootAssemblyAdvancedTimeSteppingAnalysisForModulation":
            from mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation import (
                _7127,
            )

            return self._parent._cast(
                _7127.RootAssemblyAdvancedTimeSteppingAnalysisForModulation
            )

        @property
        def assembly_advanced_time_stepping_analysis_for_modulation(
            self: "AssemblyAdvancedTimeSteppingAnalysisForModulation._Cast_AssemblyAdvancedTimeSteppingAnalysisForModulation",
        ) -> "AssemblyAdvancedTimeSteppingAnalysisForModulation":
            return self._parent

        def __getattr__(
            self: "AssemblyAdvancedTimeSteppingAnalysisForModulation._Cast_AssemblyAdvancedTimeSteppingAnalysisForModulation",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(
        self: Self,
        instance_to_wrap: "AssemblyAdvancedTimeSteppingAnalysisForModulation.TYPE",
    ):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def assembly_design(self: Self) -> "_2453.Assembly":
        """mastapy.system_model.part_model.Assembly

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AssemblyDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def assembly_load_case(self: Self) -> "_6840.AssemblyLoadCase":
        """mastapy.system_model.analyses_and_results.static_loads.AssemblyLoadCase

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AssemblyLoadCase

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def system_deflection_results(self: Self) -> "_2713.AssemblySystemDeflection":
        """mastapy.system_model.analyses_and_results.system_deflections.AssemblySystemDeflection

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SystemDeflectionResults

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def bearings(
        self: Self,
    ) -> "List[_7040.BearingAdvancedTimeSteppingAnalysisForModulation]":
        """List[mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.BearingAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Bearings

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def belt_drives(
        self: Self,
    ) -> "List[_7042.BeltDriveAdvancedTimeSteppingAnalysisForModulation]":
        """List[mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.BeltDriveAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.BeltDrives

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def bevel_differential_gear_sets(
        self: Self,
    ) -> (
        "List[_7045.BevelDifferentialGearSetAdvancedTimeSteppingAnalysisForModulation]"
    ):
        """List[mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.BevelDifferentialGearSetAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.BevelDifferentialGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def bolted_joints(
        self: Self,
    ) -> "List[_7052.BoltedJointAdvancedTimeSteppingAnalysisForModulation]":
        """List[mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.BoltedJointAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.BoltedJoints

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def bolts(
        self: Self,
    ) -> "List[_7051.BoltAdvancedTimeSteppingAnalysisForModulation]":
        """List[mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.BoltAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Bolts

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cv_ts(self: Self) -> "List[_7072.CVTAdvancedTimeSteppingAnalysisForModulation]":
        """List[mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.CVTAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CVTs

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def clutches(
        self: Self,
    ) -> "List[_7053.ClutchAdvancedTimeSteppingAnalysisForModulation]":
        """List[mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.ClutchAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Clutches

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def concept_couplings(
        self: Self,
    ) -> "List[_7058.ConceptCouplingAdvancedTimeSteppingAnalysisForModulation]":
        """List[mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.ConceptCouplingAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConceptCouplings

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def concept_gear_sets(
        self: Self,
    ) -> "List[_7063.ConceptGearSetAdvancedTimeSteppingAnalysisForModulation]":
        """List[mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.ConceptGearSetAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConceptGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cycloidal_assemblies(
        self: Self,
    ) -> "List[_7075.CycloidalAssemblyAdvancedTimeSteppingAnalysisForModulation]":
        """List[mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.CycloidalAssemblyAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CycloidalAssemblies

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cycloidal_discs(
        self: Self,
    ) -> "List[_7076.CycloidalDiscAdvancedTimeSteppingAnalysisForModulation]":
        """List[mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.CycloidalDiscAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CycloidalDiscs

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cylindrical_gear_sets(
        self: Self,
    ) -> "List[_7081.CylindricalGearSetAdvancedTimeSteppingAnalysisForModulation]":
        """List[mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.CylindricalGearSetAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CylindricalGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def fe_parts(
        self: Self,
    ) -> "List[_7088.FEPartAdvancedTimeSteppingAnalysisForModulation]":
        """List[mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.FEPartAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FEParts

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def face_gear_sets(
        self: Self,
    ) -> "List[_7087.FaceGearSetAdvancedTimeSteppingAnalysisForModulation]":
        """List[mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.FaceGearSetAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FaceGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def flexible_pin_assemblies(
        self: Self,
    ) -> "List[_7089.FlexiblePinAssemblyAdvancedTimeSteppingAnalysisForModulation]":
        """List[mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.FlexiblePinAssemblyAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FlexiblePinAssemblies

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def hypoid_gear_sets(
        self: Self,
    ) -> "List[_7097.HypoidGearSetAdvancedTimeSteppingAnalysisForModulation]":
        """List[mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.HypoidGearSetAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.HypoidGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_sets(
        self: Self,
    ) -> "List[_7104.KlingelnbergCycloPalloidHypoidGearSetAdvancedTimeSteppingAnalysisForModulation]":
        """List[mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.KlingelnbergCycloPalloidHypoidGearSetAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.KlingelnbergCycloPalloidHypoidGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_sets(
        self: Self,
    ) -> "List[_7107.KlingelnbergCycloPalloidSpiralBevelGearSetAdvancedTimeSteppingAnalysisForModulation]":
        """List[mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.KlingelnbergCycloPalloidSpiralBevelGearSetAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.KlingelnbergCycloPalloidSpiralBevelGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def mass_discs(
        self: Self,
    ) -> "List[_7108.MassDiscAdvancedTimeSteppingAnalysisForModulation]":
        """List[mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.MassDiscAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MassDiscs

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def measurement_components(
        self: Self,
    ) -> "List[_7109.MeasurementComponentAdvancedTimeSteppingAnalysisForModulation]":
        """List[mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.MeasurementComponentAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MeasurementComponents

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def oil_seals(
        self: Self,
    ) -> "List[_7111.OilSealAdvancedTimeSteppingAnalysisForModulation]":
        """List[mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.OilSealAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.OilSeals

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def part_to_part_shear_couplings(
        self: Self,
    ) -> "List[_7113.PartToPartShearCouplingAdvancedTimeSteppingAnalysisForModulation]":
        """List[mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.PartToPartShearCouplingAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PartToPartShearCouplings

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def planet_carriers(
        self: Self,
    ) -> "List[_7118.PlanetCarrierAdvancedTimeSteppingAnalysisForModulation]":
        """List[mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.PlanetCarrierAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PlanetCarriers

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def point_loads(
        self: Self,
    ) -> "List[_7119.PointLoadAdvancedTimeSteppingAnalysisForModulation]":
        """List[mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.PointLoadAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PointLoads

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def power_loads(
        self: Self,
    ) -> "List[_7120.PowerLoadAdvancedTimeSteppingAnalysisForModulation]":
        """List[mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.PowerLoadAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PowerLoads

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def ring_pins(
        self: Self,
    ) -> "List[_7122.RingPinsAdvancedTimeSteppingAnalysisForModulation]":
        """List[mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.RingPinsAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RingPins

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def rolling_ring_assemblies(
        self: Self,
    ) -> "List[_7125.RollingRingAssemblyAdvancedTimeSteppingAnalysisForModulation]":
        """List[mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.RollingRingAssemblyAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RollingRingAssemblies

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def shaft_hub_connections(
        self: Self,
    ) -> "List[_7129.ShaftHubConnectionAdvancedTimeSteppingAnalysisForModulation]":
        """List[mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.ShaftHubConnectionAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ShaftHubConnections

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def shafts(
        self: Self,
    ) -> "List[_7128.ShaftAdvancedTimeSteppingAnalysisForModulation]":
        """List[mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.ShaftAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Shafts

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def spiral_bevel_gear_sets(
        self: Self,
    ) -> "List[_7134.SpiralBevelGearSetAdvancedTimeSteppingAnalysisForModulation]":
        """List[mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.SpiralBevelGearSetAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SpiralBevelGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def spring_dampers(
        self: Self,
    ) -> "List[_7135.SpringDamperAdvancedTimeSteppingAnalysisForModulation]":
        """List[mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.SpringDamperAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SpringDampers

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def straight_bevel_diff_gear_sets(
        self: Self,
    ) -> (
        "List[_7140.StraightBevelDiffGearSetAdvancedTimeSteppingAnalysisForModulation]"
    ):
        """List[mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.StraightBevelDiffGearSetAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.StraightBevelDiffGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def straight_bevel_gear_sets(
        self: Self,
    ) -> "List[_7143.StraightBevelGearSetAdvancedTimeSteppingAnalysisForModulation]":
        """List[mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.StraightBevelGearSetAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.StraightBevelGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def synchronisers(
        self: Self,
    ) -> "List[_7146.SynchroniserAdvancedTimeSteppingAnalysisForModulation]":
        """List[mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.SynchroniserAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Synchronisers

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def torque_converters(
        self: Self,
    ) -> "List[_7150.TorqueConverterAdvancedTimeSteppingAnalysisForModulation]":
        """List[mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.TorqueConverterAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TorqueConverters

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def unbalanced_masses(
        self: Self,
    ) -> "List[_7154.UnbalancedMassAdvancedTimeSteppingAnalysisForModulation]":
        """List[mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.UnbalancedMassAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.UnbalancedMasses

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def worm_gear_sets(
        self: Self,
    ) -> "List[_7158.WormGearSetAdvancedTimeSteppingAnalysisForModulation]":
        """List[mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.WormGearSetAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.WormGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def zerol_bevel_gear_sets(
        self: Self,
    ) -> "List[_7161.ZerolBevelGearSetAdvancedTimeSteppingAnalysisForModulation]":
        """List[mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.ZerolBevelGearSetAdvancedTimeSteppingAnalysisForModulation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ZerolBevelGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(
        self: Self,
    ) -> "AssemblyAdvancedTimeSteppingAnalysisForModulation._Cast_AssemblyAdvancedTimeSteppingAnalysisForModulation":
        return self._Cast_AssemblyAdvancedTimeSteppingAnalysisForModulation(self)



"""RollerRaceProfilePoint"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy import _0
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_ROLLER_RACE_PROFILE_POINT = python_net_import(
    "SMT.MastaAPI.Bearings.RollerBearingProfiles", "RollerRaceProfilePoint"
)

if TYPE_CHECKING:
    from mastapy.bearings.roller_bearing_profiles import _1960


__docformat__ = "restructuredtext en"
__all__ = ("RollerRaceProfilePoint",)


Self = TypeVar("Self", bound="RollerRaceProfilePoint")


class RollerRaceProfilePoint(_0.APIBase):
    """RollerRaceProfilePoint

    This is a mastapy class.
    """

    TYPE = _ROLLER_RACE_PROFILE_POINT
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_RollerRaceProfilePoint")

    class _Cast_RollerRaceProfilePoint:
        """Special nested class for casting RollerRaceProfilePoint to subclasses."""

        def __init__(
            self: "RollerRaceProfilePoint._Cast_RollerRaceProfilePoint",
            parent: "RollerRaceProfilePoint",
        ):
            self._parent = parent

        @property
        def user_specified_roller_race_profile_point(
            self: "RollerRaceProfilePoint._Cast_RollerRaceProfilePoint",
        ) -> "_1960.UserSpecifiedRollerRaceProfilePoint":
            from mastapy.bearings.roller_bearing_profiles import _1960

            return self._parent._cast(_1960.UserSpecifiedRollerRaceProfilePoint)

        @property
        def roller_race_profile_point(
            self: "RollerRaceProfilePoint._Cast_RollerRaceProfilePoint",
        ) -> "RollerRaceProfilePoint":
            return self._parent

        def __getattr__(
            self: "RollerRaceProfilePoint._Cast_RollerRaceProfilePoint", name: str
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "RollerRaceProfilePoint.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def offset_from_roller_centre(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.OffsetFromRollerCentre

        if temp is None:
            return 0.0

        return temp

    @property
    def race_deviation(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RaceDeviation

        if temp is None:
            return 0.0

        return temp

    @property
    def roller_deviation(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RollerDeviation

        if temp is None:
            return 0.0

        return temp

    @property
    def total_deviation(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TotalDeviation

        if temp is None:
            return 0.0

        return temp

    @property
    def cast_to(self: Self) -> "RollerRaceProfilePoint._Cast_RollerRaceProfilePoint":
        return self._Cast_RollerRaceProfilePoint(self)



"""MountableComponent"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy._internal.type_enforcement import enforce_parameter_types
from mastapy._internal import constructor
from mastapy.system_model.part_model import _2464
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_MOUNTABLE_COMPONENT = python_net_import(
    "SMT.MastaAPI.SystemModel.PartModel", "MountableComponent"
)

if TYPE_CHECKING:
    from mastapy.system_model.part_model import (
        _2455,
        _2465,
        _2459,
        _2467,
        _2482,
        _2483,
        _2486,
        _2489,
        _2491,
        _2492,
        _2497,
        _2499,
        _2488,
    )
    from mastapy.system_model.connections_and_sockets import _2292, _2296, _2289
    from mastapy.system_model.part_model.gears import (
        _2533,
        _2535,
        _2537,
        _2538,
        _2539,
        _2541,
        _2543,
        _2545,
        _2547,
        _2548,
        _2550,
        _2554,
        _2556,
        _2558,
        _2560,
        _2563,
        _2565,
        _2567,
        _2569,
        _2570,
        _2571,
        _2573,
    )
    from mastapy.system_model.part_model.cycloidal import _2590
    from mastapy.system_model.part_model.couplings import (
        _2599,
        _2602,
        _2605,
        _2608,
        _2610,
        _2611,
        _2617,
        _2619,
        _2622,
        _2625,
        _2626,
        _2627,
        _2629,
        _2631,
    )
    from mastapy.system_model import _2223


__docformat__ = "restructuredtext en"
__all__ = ("MountableComponent",)


Self = TypeVar("Self", bound="MountableComponent")


class MountableComponent(_2464.Component):
    """MountableComponent

    This is a mastapy class.
    """

    TYPE = _MOUNTABLE_COMPONENT
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_MountableComponent")

    class _Cast_MountableComponent:
        """Special nested class for casting MountableComponent to subclasses."""

        def __init__(
            self: "MountableComponent._Cast_MountableComponent",
            parent: "MountableComponent",
        ):
            self._parent = parent

        @property
        def component(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2464.Component":
            return self._parent._cast(_2464.Component)

        @property
        def part(self: "MountableComponent._Cast_MountableComponent") -> "_2488.Part":
            from mastapy.system_model.part_model import _2488

            return self._parent._cast(_2488.Part)

        @property
        def design_entity(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2223.DesignEntity":
            from mastapy.system_model import _2223

            return self._parent._cast(_2223.DesignEntity)

        @property
        def bearing(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2459.Bearing":
            from mastapy.system_model.part_model import _2459

            return self._parent._cast(_2459.Bearing)

        @property
        def connector(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2467.Connector":
            from mastapy.system_model.part_model import _2467

            return self._parent._cast(_2467.Connector)

        @property
        def mass_disc(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2482.MassDisc":
            from mastapy.system_model.part_model import _2482

            return self._parent._cast(_2482.MassDisc)

        @property
        def measurement_component(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2483.MeasurementComponent":
            from mastapy.system_model.part_model import _2483

            return self._parent._cast(_2483.MeasurementComponent)

        @property
        def oil_seal(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2486.OilSeal":
            from mastapy.system_model.part_model import _2486

            return self._parent._cast(_2486.OilSeal)

        @property
        def planet_carrier(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2489.PlanetCarrier":
            from mastapy.system_model.part_model import _2489

            return self._parent._cast(_2489.PlanetCarrier)

        @property
        def point_load(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2491.PointLoad":
            from mastapy.system_model.part_model import _2491

            return self._parent._cast(_2491.PointLoad)

        @property
        def power_load(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2492.PowerLoad":
            from mastapy.system_model.part_model import _2492

            return self._parent._cast(_2492.PowerLoad)

        @property
        def unbalanced_mass(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2497.UnbalancedMass":
            from mastapy.system_model.part_model import _2497

            return self._parent._cast(_2497.UnbalancedMass)

        @property
        def virtual_component(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2499.VirtualComponent":
            from mastapy.system_model.part_model import _2499

            return self._parent._cast(_2499.VirtualComponent)

        @property
        def agma_gleason_conical_gear(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2533.AGMAGleasonConicalGear":
            from mastapy.system_model.part_model.gears import _2533

            return self._parent._cast(_2533.AGMAGleasonConicalGear)

        @property
        def bevel_differential_gear(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2535.BevelDifferentialGear":
            from mastapy.system_model.part_model.gears import _2535

            return self._parent._cast(_2535.BevelDifferentialGear)

        @property
        def bevel_differential_planet_gear(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2537.BevelDifferentialPlanetGear":
            from mastapy.system_model.part_model.gears import _2537

            return self._parent._cast(_2537.BevelDifferentialPlanetGear)

        @property
        def bevel_differential_sun_gear(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2538.BevelDifferentialSunGear":
            from mastapy.system_model.part_model.gears import _2538

            return self._parent._cast(_2538.BevelDifferentialSunGear)

        @property
        def bevel_gear(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2539.BevelGear":
            from mastapy.system_model.part_model.gears import _2539

            return self._parent._cast(_2539.BevelGear)

        @property
        def concept_gear(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2541.ConceptGear":
            from mastapy.system_model.part_model.gears import _2541

            return self._parent._cast(_2541.ConceptGear)

        @property
        def conical_gear(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2543.ConicalGear":
            from mastapy.system_model.part_model.gears import _2543

            return self._parent._cast(_2543.ConicalGear)

        @property
        def cylindrical_gear(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2545.CylindricalGear":
            from mastapy.system_model.part_model.gears import _2545

            return self._parent._cast(_2545.CylindricalGear)

        @property
        def cylindrical_planet_gear(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2547.CylindricalPlanetGear":
            from mastapy.system_model.part_model.gears import _2547

            return self._parent._cast(_2547.CylindricalPlanetGear)

        @property
        def face_gear(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2548.FaceGear":
            from mastapy.system_model.part_model.gears import _2548

            return self._parent._cast(_2548.FaceGear)

        @property
        def gear(self: "MountableComponent._Cast_MountableComponent") -> "_2550.Gear":
            from mastapy.system_model.part_model.gears import _2550

            return self._parent._cast(_2550.Gear)

        @property
        def hypoid_gear(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2554.HypoidGear":
            from mastapy.system_model.part_model.gears import _2554

            return self._parent._cast(_2554.HypoidGear)

        @property
        def klingelnberg_cyclo_palloid_conical_gear(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2556.KlingelnbergCycloPalloidConicalGear":
            from mastapy.system_model.part_model.gears import _2556

            return self._parent._cast(_2556.KlingelnbergCycloPalloidConicalGear)

        @property
        def klingelnberg_cyclo_palloid_hypoid_gear(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2558.KlingelnbergCycloPalloidHypoidGear":
            from mastapy.system_model.part_model.gears import _2558

            return self._parent._cast(_2558.KlingelnbergCycloPalloidHypoidGear)

        @property
        def klingelnberg_cyclo_palloid_spiral_bevel_gear(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2560.KlingelnbergCycloPalloidSpiralBevelGear":
            from mastapy.system_model.part_model.gears import _2560

            return self._parent._cast(_2560.KlingelnbergCycloPalloidSpiralBevelGear)

        @property
        def spiral_bevel_gear(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2563.SpiralBevelGear":
            from mastapy.system_model.part_model.gears import _2563

            return self._parent._cast(_2563.SpiralBevelGear)

        @property
        def straight_bevel_diff_gear(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2565.StraightBevelDiffGear":
            from mastapy.system_model.part_model.gears import _2565

            return self._parent._cast(_2565.StraightBevelDiffGear)

        @property
        def straight_bevel_gear(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2567.StraightBevelGear":
            from mastapy.system_model.part_model.gears import _2567

            return self._parent._cast(_2567.StraightBevelGear)

        @property
        def straight_bevel_planet_gear(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2569.StraightBevelPlanetGear":
            from mastapy.system_model.part_model.gears import _2569

            return self._parent._cast(_2569.StraightBevelPlanetGear)

        @property
        def straight_bevel_sun_gear(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2570.StraightBevelSunGear":
            from mastapy.system_model.part_model.gears import _2570

            return self._parent._cast(_2570.StraightBevelSunGear)

        @property
        def worm_gear(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2571.WormGear":
            from mastapy.system_model.part_model.gears import _2571

            return self._parent._cast(_2571.WormGear)

        @property
        def zerol_bevel_gear(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2573.ZerolBevelGear":
            from mastapy.system_model.part_model.gears import _2573

            return self._parent._cast(_2573.ZerolBevelGear)

        @property
        def ring_pins(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2590.RingPins":
            from mastapy.system_model.part_model.cycloidal import _2590

            return self._parent._cast(_2590.RingPins)

        @property
        def clutch_half(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2599.ClutchHalf":
            from mastapy.system_model.part_model.couplings import _2599

            return self._parent._cast(_2599.ClutchHalf)

        @property
        def concept_coupling_half(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2602.ConceptCouplingHalf":
            from mastapy.system_model.part_model.couplings import _2602

            return self._parent._cast(_2602.ConceptCouplingHalf)

        @property
        def coupling_half(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2605.CouplingHalf":
            from mastapy.system_model.part_model.couplings import _2605

            return self._parent._cast(_2605.CouplingHalf)

        @property
        def cvt_pulley(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2608.CVTPulley":
            from mastapy.system_model.part_model.couplings import _2608

            return self._parent._cast(_2608.CVTPulley)

        @property
        def part_to_part_shear_coupling_half(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2610.PartToPartShearCouplingHalf":
            from mastapy.system_model.part_model.couplings import _2610

            return self._parent._cast(_2610.PartToPartShearCouplingHalf)

        @property
        def pulley(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2611.Pulley":
            from mastapy.system_model.part_model.couplings import _2611

            return self._parent._cast(_2611.Pulley)

        @property
        def rolling_ring(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2617.RollingRing":
            from mastapy.system_model.part_model.couplings import _2617

            return self._parent._cast(_2617.RollingRing)

        @property
        def shaft_hub_connection(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2619.ShaftHubConnection":
            from mastapy.system_model.part_model.couplings import _2619

            return self._parent._cast(_2619.ShaftHubConnection)

        @property
        def spring_damper_half(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2622.SpringDamperHalf":
            from mastapy.system_model.part_model.couplings import _2622

            return self._parent._cast(_2622.SpringDamperHalf)

        @property
        def synchroniser_half(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2625.SynchroniserHalf":
            from mastapy.system_model.part_model.couplings import _2625

            return self._parent._cast(_2625.SynchroniserHalf)

        @property
        def synchroniser_part(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2626.SynchroniserPart":
            from mastapy.system_model.part_model.couplings import _2626

            return self._parent._cast(_2626.SynchroniserPart)

        @property
        def synchroniser_sleeve(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2627.SynchroniserSleeve":
            from mastapy.system_model.part_model.couplings import _2627

            return self._parent._cast(_2627.SynchroniserSleeve)

        @property
        def torque_converter_pump(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2629.TorqueConverterPump":
            from mastapy.system_model.part_model.couplings import _2629

            return self._parent._cast(_2629.TorqueConverterPump)

        @property
        def torque_converter_turbine(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "_2631.TorqueConverterTurbine":
            from mastapy.system_model.part_model.couplings import _2631

            return self._parent._cast(_2631.TorqueConverterTurbine)

        @property
        def mountable_component(
            self: "MountableComponent._Cast_MountableComponent",
        ) -> "MountableComponent":
            return self._parent

        def __getattr__(self: "MountableComponent._Cast_MountableComponent", name: str):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "MountableComponent.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def rotation_about_axis(self: Self) -> "float":
        """float"""
        temp = self.wrapped.RotationAboutAxis

        if temp is None:
            return 0.0

        return temp

    @rotation_about_axis.setter
    @enforce_parameter_types
    def rotation_about_axis(self: Self, value: "float"):
        self.wrapped.RotationAboutAxis = float(value) if value is not None else 0.0

    @property
    def inner_component(self: Self) -> "_2455.AbstractShaft":
        """mastapy.system_model.part_model.AbstractShaft

        Note:
            This property is readonly.
        """
        temp = self.wrapped.InnerComponent

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def inner_connection(self: Self) -> "_2292.Connection":
        """mastapy.system_model.connections_and_sockets.Connection

        Note:
            This property is readonly.
        """
        temp = self.wrapped.InnerConnection

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def inner_socket(self: Self) -> "_2296.CylindricalSocket":
        """mastapy.system_model.connections_and_sockets.CylindricalSocket

        Note:
            This property is readonly.
        """
        temp = self.wrapped.InnerSocket

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def is_mounted(self: Self) -> "bool":
        """bool

        Note:
            This property is readonly.
        """
        temp = self.wrapped.IsMounted

        if temp is None:
            return False

        return temp

    @enforce_parameter_types
    def mount_on(
        self: Self, shaft: "_2455.AbstractShaft", offset: "float" = float("nan")
    ) -> "_2289.CoaxialConnection":
        """mastapy.system_model.connections_and_sockets.CoaxialConnection

        Args:
            shaft (mastapy.system_model.part_model.AbstractShaft)
            offset (float, optional)
        """
        offset = float(offset)
        method_result = self.wrapped.MountOn(
            shaft.wrapped if shaft else None, offset if offset else 0.0
        )
        type_ = method_result.GetType()
        return (
            constructor.new(type_.Namespace, type_.Name)(method_result)
            if method_result is not None
            else None
        )

    @enforce_parameter_types
    def try_mount_on(
        self: Self, shaft: "_2455.AbstractShaft", offset: "float" = float("nan")
    ) -> "_2465.ComponentsConnectedResult":
        """mastapy.system_model.part_model.ComponentsConnectedResult

        Args:
            shaft (mastapy.system_model.part_model.AbstractShaft)
            offset (float, optional)
        """
        offset = float(offset)
        method_result = self.wrapped.TryMountOn(
            shaft.wrapped if shaft else None, offset if offset else 0.0
        )
        type_ = method_result.GetType()
        return (
            constructor.new(type_.Namespace, type_.Name)(method_result)
            if method_result is not None
            else None
        )

    @property
    def cast_to(self: Self) -> "MountableComponent._Cast_MountableComponent":
        return self._Cast_MountableComponent(self)



"""__init__.py"""

import sys
from typing import TYPE_CHECKING

from lazy_imports import LazyImporter


if TYPE_CHECKING:
    from ._6029 import AbstractAssemblyHarmonicAnalysisOfSingleExcitation
    from ._6030 import AbstractShaftHarmonicAnalysisOfSingleExcitation
    from ._6031 import AbstractShaftOrHousingHarmonicAnalysisOfSingleExcitation
    from ._6032 import (
        AbstractShaftToMountableComponentConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from ._6033 import AGMAGleasonConicalGearHarmonicAnalysisOfSingleExcitation
    from ._6034 import AGMAGleasonConicalGearMeshHarmonicAnalysisOfSingleExcitation
    from ._6035 import AGMAGleasonConicalGearSetHarmonicAnalysisOfSingleExcitation
    from ._6036 import AssemblyHarmonicAnalysisOfSingleExcitation
    from ._6037 import BearingHarmonicAnalysisOfSingleExcitation
    from ._6038 import BeltConnectionHarmonicAnalysisOfSingleExcitation
    from ._6039 import BeltDriveHarmonicAnalysisOfSingleExcitation
    from ._6040 import BevelDifferentialGearHarmonicAnalysisOfSingleExcitation
    from ._6041 import BevelDifferentialGearMeshHarmonicAnalysisOfSingleExcitation
    from ._6042 import BevelDifferentialGearSetHarmonicAnalysisOfSingleExcitation
    from ._6043 import BevelDifferentialPlanetGearHarmonicAnalysisOfSingleExcitation
    from ._6044 import BevelDifferentialSunGearHarmonicAnalysisOfSingleExcitation
    from ._6045 import BevelGearHarmonicAnalysisOfSingleExcitation
    from ._6046 import BevelGearMeshHarmonicAnalysisOfSingleExcitation
    from ._6047 import BevelGearSetHarmonicAnalysisOfSingleExcitation
    from ._6048 import BoltedJointHarmonicAnalysisOfSingleExcitation
    from ._6049 import BoltHarmonicAnalysisOfSingleExcitation
    from ._6050 import ClutchConnectionHarmonicAnalysisOfSingleExcitation
    from ._6051 import ClutchHalfHarmonicAnalysisOfSingleExcitation
    from ._6052 import ClutchHarmonicAnalysisOfSingleExcitation
    from ._6053 import CoaxialConnectionHarmonicAnalysisOfSingleExcitation
    from ._6054 import ComponentHarmonicAnalysisOfSingleExcitation
    from ._6055 import ConceptCouplingConnectionHarmonicAnalysisOfSingleExcitation
    from ._6056 import ConceptCouplingHalfHarmonicAnalysisOfSingleExcitation
    from ._6057 import ConceptCouplingHarmonicAnalysisOfSingleExcitation
    from ._6058 import ConceptGearHarmonicAnalysisOfSingleExcitation
    from ._6059 import ConceptGearMeshHarmonicAnalysisOfSingleExcitation
    from ._6060 import ConceptGearSetHarmonicAnalysisOfSingleExcitation
    from ._6061 import ConicalGearHarmonicAnalysisOfSingleExcitation
    from ._6062 import ConicalGearMeshHarmonicAnalysisOfSingleExcitation
    from ._6063 import ConicalGearSetHarmonicAnalysisOfSingleExcitation
    from ._6064 import ConnectionHarmonicAnalysisOfSingleExcitation
    from ._6065 import ConnectorHarmonicAnalysisOfSingleExcitation
    from ._6066 import CouplingConnectionHarmonicAnalysisOfSingleExcitation
    from ._6067 import CouplingHalfHarmonicAnalysisOfSingleExcitation
    from ._6068 import CouplingHarmonicAnalysisOfSingleExcitation
    from ._6069 import CVTBeltConnectionHarmonicAnalysisOfSingleExcitation
    from ._6070 import CVTHarmonicAnalysisOfSingleExcitation
    from ._6071 import CVTPulleyHarmonicAnalysisOfSingleExcitation
    from ._6072 import CycloidalAssemblyHarmonicAnalysisOfSingleExcitation
    from ._6073 import (
        CycloidalDiscCentralBearingConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from ._6074 import CycloidalDiscHarmonicAnalysisOfSingleExcitation
    from ._6075 import (
        CycloidalDiscPlanetaryBearingConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from ._6076 import CylindricalGearHarmonicAnalysisOfSingleExcitation
    from ._6077 import CylindricalGearMeshHarmonicAnalysisOfSingleExcitation
    from ._6078 import CylindricalGearSetHarmonicAnalysisOfSingleExcitation
    from ._6079 import CylindricalPlanetGearHarmonicAnalysisOfSingleExcitation
    from ._6080 import DatumHarmonicAnalysisOfSingleExcitation
    from ._6081 import ExternalCADModelHarmonicAnalysisOfSingleExcitation
    from ._6082 import FaceGearHarmonicAnalysisOfSingleExcitation
    from ._6083 import FaceGearMeshHarmonicAnalysisOfSingleExcitation
    from ._6084 import FaceGearSetHarmonicAnalysisOfSingleExcitation
    from ._6085 import FEPartHarmonicAnalysisOfSingleExcitation
    from ._6086 import FlexiblePinAssemblyHarmonicAnalysisOfSingleExcitation
    from ._6087 import GearHarmonicAnalysisOfSingleExcitation
    from ._6088 import GearMeshHarmonicAnalysisOfSingleExcitation
    from ._6089 import GearSetHarmonicAnalysisOfSingleExcitation
    from ._6090 import GuideDxfModelHarmonicAnalysisOfSingleExcitation
    from ._6091 import HarmonicAnalysisOfSingleExcitation
    from ._6092 import HypoidGearHarmonicAnalysisOfSingleExcitation
    from ._6093 import HypoidGearMeshHarmonicAnalysisOfSingleExcitation
    from ._6094 import HypoidGearSetHarmonicAnalysisOfSingleExcitation
    from ._6095 import (
        InterMountableComponentConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from ._6096 import (
        KlingelnbergCycloPalloidConicalGearHarmonicAnalysisOfSingleExcitation,
    )
    from ._6097 import (
        KlingelnbergCycloPalloidConicalGearMeshHarmonicAnalysisOfSingleExcitation,
    )
    from ._6098 import (
        KlingelnbergCycloPalloidConicalGearSetHarmonicAnalysisOfSingleExcitation,
    )
    from ._6099 import (
        KlingelnbergCycloPalloidHypoidGearHarmonicAnalysisOfSingleExcitation,
    )
    from ._6100 import (
        KlingelnbergCycloPalloidHypoidGearMeshHarmonicAnalysisOfSingleExcitation,
    )
    from ._6101 import (
        KlingelnbergCycloPalloidHypoidGearSetHarmonicAnalysisOfSingleExcitation,
    )
    from ._6102 import (
        KlingelnbergCycloPalloidSpiralBevelGearHarmonicAnalysisOfSingleExcitation,
    )
    from ._6103 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshHarmonicAnalysisOfSingleExcitation,
    )
    from ._6104 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetHarmonicAnalysisOfSingleExcitation,
    )
    from ._6105 import MassDiscHarmonicAnalysisOfSingleExcitation
    from ._6106 import MeasurementComponentHarmonicAnalysisOfSingleExcitation
    from ._6107 import ModalAnalysisForHarmonicAnalysis
    from ._6108 import MountableComponentHarmonicAnalysisOfSingleExcitation
    from ._6109 import OilSealHarmonicAnalysisOfSingleExcitation
    from ._6110 import PartHarmonicAnalysisOfSingleExcitation
    from ._6111 import (
        PartToPartShearCouplingConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from ._6112 import PartToPartShearCouplingHalfHarmonicAnalysisOfSingleExcitation
    from ._6113 import PartToPartShearCouplingHarmonicAnalysisOfSingleExcitation
    from ._6114 import PlanetaryConnectionHarmonicAnalysisOfSingleExcitation
    from ._6115 import PlanetaryGearSetHarmonicAnalysisOfSingleExcitation
    from ._6116 import PlanetCarrierHarmonicAnalysisOfSingleExcitation
    from ._6117 import PointLoadHarmonicAnalysisOfSingleExcitation
    from ._6118 import PowerLoadHarmonicAnalysisOfSingleExcitation
    from ._6119 import PulleyHarmonicAnalysisOfSingleExcitation
    from ._6120 import RingPinsHarmonicAnalysisOfSingleExcitation
    from ._6121 import RingPinsToDiscConnectionHarmonicAnalysisOfSingleExcitation
    from ._6122 import RollingRingAssemblyHarmonicAnalysisOfSingleExcitation
    from ._6123 import RollingRingConnectionHarmonicAnalysisOfSingleExcitation
    from ._6124 import RollingRingHarmonicAnalysisOfSingleExcitation
    from ._6125 import RootAssemblyHarmonicAnalysisOfSingleExcitation
    from ._6126 import ShaftHarmonicAnalysisOfSingleExcitation
    from ._6127 import ShaftHubConnectionHarmonicAnalysisOfSingleExcitation
    from ._6128 import (
        ShaftToMountableComponentConnectionHarmonicAnalysisOfSingleExcitation,
    )
    from ._6129 import SpecialisedAssemblyHarmonicAnalysisOfSingleExcitation
    from ._6130 import SpiralBevelGearHarmonicAnalysisOfSingleExcitation
    from ._6131 import SpiralBevelGearMeshHarmonicAnalysisOfSingleExcitation
    from ._6132 import SpiralBevelGearSetHarmonicAnalysisOfSingleExcitation
    from ._6133 import SpringDamperConnectionHarmonicAnalysisOfSingleExcitation
    from ._6134 import SpringDamperHalfHarmonicAnalysisOfSingleExcitation
    from ._6135 import SpringDamperHarmonicAnalysisOfSingleExcitation
    from ._6136 import StraightBevelDiffGearHarmonicAnalysisOfSingleExcitation
    from ._6137 import StraightBevelDiffGearMeshHarmonicAnalysisOfSingleExcitation
    from ._6138 import StraightBevelDiffGearSetHarmonicAnalysisOfSingleExcitation
    from ._6139 import StraightBevelGearHarmonicAnalysisOfSingleExcitation
    from ._6140 import StraightBevelGearMeshHarmonicAnalysisOfSingleExcitation
    from ._6141 import StraightBevelGearSetHarmonicAnalysisOfSingleExcitation
    from ._6142 import StraightBevelPlanetGearHarmonicAnalysisOfSingleExcitation
    from ._6143 import StraightBevelSunGearHarmonicAnalysisOfSingleExcitation
    from ._6144 import SynchroniserHalfHarmonicAnalysisOfSingleExcitation
    from ._6145 import SynchroniserHarmonicAnalysisOfSingleExcitation
    from ._6146 import SynchroniserPartHarmonicAnalysisOfSingleExcitation
    from ._6147 import SynchroniserSleeveHarmonicAnalysisOfSingleExcitation
    from ._6148 import TorqueConverterConnectionHarmonicAnalysisOfSingleExcitation
    from ._6149 import TorqueConverterHarmonicAnalysisOfSingleExcitation
    from ._6150 import TorqueConverterPumpHarmonicAnalysisOfSingleExcitation
    from ._6151 import TorqueConverterTurbineHarmonicAnalysisOfSingleExcitation
    from ._6152 import UnbalancedMassHarmonicAnalysisOfSingleExcitation
    from ._6153 import VirtualComponentHarmonicAnalysisOfSingleExcitation
    from ._6154 import WormGearHarmonicAnalysisOfSingleExcitation
    from ._6155 import WormGearMeshHarmonicAnalysisOfSingleExcitation
    from ._6156 import WormGearSetHarmonicAnalysisOfSingleExcitation
    from ._6157 import ZerolBevelGearHarmonicAnalysisOfSingleExcitation
    from ._6158 import ZerolBevelGearMeshHarmonicAnalysisOfSingleExcitation
    from ._6159 import ZerolBevelGearSetHarmonicAnalysisOfSingleExcitation
else:
    import_structure = {
        "_6029": ["AbstractAssemblyHarmonicAnalysisOfSingleExcitation"],
        "_6030": ["AbstractShaftHarmonicAnalysisOfSingleExcitation"],
        "_6031": ["AbstractShaftOrHousingHarmonicAnalysisOfSingleExcitation"],
        "_6032": [
            "AbstractShaftToMountableComponentConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_6033": ["AGMAGleasonConicalGearHarmonicAnalysisOfSingleExcitation"],
        "_6034": ["AGMAGleasonConicalGearMeshHarmonicAnalysisOfSingleExcitation"],
        "_6035": ["AGMAGleasonConicalGearSetHarmonicAnalysisOfSingleExcitation"],
        "_6036": ["AssemblyHarmonicAnalysisOfSingleExcitation"],
        "_6037": ["BearingHarmonicAnalysisOfSingleExcitation"],
        "_6038": ["BeltConnectionHarmonicAnalysisOfSingleExcitation"],
        "_6039": ["BeltDriveHarmonicAnalysisOfSingleExcitation"],
        "_6040": ["BevelDifferentialGearHarmonicAnalysisOfSingleExcitation"],
        "_6041": ["BevelDifferentialGearMeshHarmonicAnalysisOfSingleExcitation"],
        "_6042": ["BevelDifferentialGearSetHarmonicAnalysisOfSingleExcitation"],
        "_6043": ["BevelDifferentialPlanetGearHarmonicAnalysisOfSingleExcitation"],
        "_6044": ["BevelDifferentialSunGearHarmonicAnalysisOfSingleExcitation"],
        "_6045": ["BevelGearHarmonicAnalysisOfSingleExcitation"],
        "_6046": ["BevelGearMeshHarmonicAnalysisOfSingleExcitation"],
        "_6047": ["BevelGearSetHarmonicAnalysisOfSingleExcitation"],
        "_6048": ["BoltedJointHarmonicAnalysisOfSingleExcitation"],
        "_6049": ["BoltHarmonicAnalysisOfSingleExcitation"],
        "_6050": ["ClutchConnectionHarmonicAnalysisOfSingleExcitation"],
        "_6051": ["ClutchHalfHarmonicAnalysisOfSingleExcitation"],
        "_6052": ["ClutchHarmonicAnalysisOfSingleExcitation"],
        "_6053": ["CoaxialConnectionHarmonicAnalysisOfSingleExcitation"],
        "_6054": ["ComponentHarmonicAnalysisOfSingleExcitation"],
        "_6055": ["ConceptCouplingConnectionHarmonicAnalysisOfSingleExcitation"],
        "_6056": ["ConceptCouplingHalfHarmonicAnalysisOfSingleExcitation"],
        "_6057": ["ConceptCouplingHarmonicAnalysisOfSingleExcitation"],
        "_6058": ["ConceptGearHarmonicAnalysisOfSingleExcitation"],
        "_6059": ["ConceptGearMeshHarmonicAnalysisOfSingleExcitation"],
        "_6060": ["ConceptGearSetHarmonicAnalysisOfSingleExcitation"],
        "_6061": ["ConicalGearHarmonicAnalysisOfSingleExcitation"],
        "_6062": ["ConicalGearMeshHarmonicAnalysisOfSingleExcitation"],
        "_6063": ["ConicalGearSetHarmonicAnalysisOfSingleExcitation"],
        "_6064": ["ConnectionHarmonicAnalysisOfSingleExcitation"],
        "_6065": ["ConnectorHarmonicAnalysisOfSingleExcitation"],
        "_6066": ["CouplingConnectionHarmonicAnalysisOfSingleExcitation"],
        "_6067": ["CouplingHalfHarmonicAnalysisOfSingleExcitation"],
        "_6068": ["CouplingHarmonicAnalysisOfSingleExcitation"],
        "_6069": ["CVTBeltConnectionHarmonicAnalysisOfSingleExcitation"],
        "_6070": ["CVTHarmonicAnalysisOfSingleExcitation"],
        "_6071": ["CVTPulleyHarmonicAnalysisOfSingleExcitation"],
        "_6072": ["CycloidalAssemblyHarmonicAnalysisOfSingleExcitation"],
        "_6073": [
            "CycloidalDiscCentralBearingConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_6074": ["CycloidalDiscHarmonicAnalysisOfSingleExcitation"],
        "_6075": [
            "CycloidalDiscPlanetaryBearingConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_6076": ["CylindricalGearHarmonicAnalysisOfSingleExcitation"],
        "_6077": ["CylindricalGearMeshHarmonicAnalysisOfSingleExcitation"],
        "_6078": ["CylindricalGearSetHarmonicAnalysisOfSingleExcitation"],
        "_6079": ["CylindricalPlanetGearHarmonicAnalysisOfSingleExcitation"],
        "_6080": ["DatumHarmonicAnalysisOfSingleExcitation"],
        "_6081": ["ExternalCADModelHarmonicAnalysisOfSingleExcitation"],
        "_6082": ["FaceGearHarmonicAnalysisOfSingleExcitation"],
        "_6083": ["FaceGearMeshHarmonicAnalysisOfSingleExcitation"],
        "_6084": ["FaceGearSetHarmonicAnalysisOfSingleExcitation"],
        "_6085": ["FEPartHarmonicAnalysisOfSingleExcitation"],
        "_6086": ["FlexiblePinAssemblyHarmonicAnalysisOfSingleExcitation"],
        "_6087": ["GearHarmonicAnalysisOfSingleExcitation"],
        "_6088": ["GearMeshHarmonicAnalysisOfSingleExcitation"],
        "_6089": ["GearSetHarmonicAnalysisOfSingleExcitation"],
        "_6090": ["GuideDxfModelHarmonicAnalysisOfSingleExcitation"],
        "_6091": ["HarmonicAnalysisOfSingleExcitation"],
        "_6092": ["HypoidGearHarmonicAnalysisOfSingleExcitation"],
        "_6093": ["HypoidGearMeshHarmonicAnalysisOfSingleExcitation"],
        "_6094": ["HypoidGearSetHarmonicAnalysisOfSingleExcitation"],
        "_6095": [
            "InterMountableComponentConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_6096": [
            "KlingelnbergCycloPalloidConicalGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_6097": [
            "KlingelnbergCycloPalloidConicalGearMeshHarmonicAnalysisOfSingleExcitation"
        ],
        "_6098": [
            "KlingelnbergCycloPalloidConicalGearSetHarmonicAnalysisOfSingleExcitation"
        ],
        "_6099": [
            "KlingelnbergCycloPalloidHypoidGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_6100": [
            "KlingelnbergCycloPalloidHypoidGearMeshHarmonicAnalysisOfSingleExcitation"
        ],
        "_6101": [
            "KlingelnbergCycloPalloidHypoidGearSetHarmonicAnalysisOfSingleExcitation"
        ],
        "_6102": [
            "KlingelnbergCycloPalloidSpiralBevelGearHarmonicAnalysisOfSingleExcitation"
        ],
        "_6103": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshHarmonicAnalysisOfSingleExcitation"
        ],
        "_6104": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetHarmonicAnalysisOfSingleExcitation"
        ],
        "_6105": ["MassDiscHarmonicAnalysisOfSingleExcitation"],
        "_6106": ["MeasurementComponentHarmonicAnalysisOfSingleExcitation"],
        "_6107": ["ModalAnalysisForHarmonicAnalysis"],
        "_6108": ["MountableComponentHarmonicAnalysisOfSingleExcitation"],
        "_6109": ["OilSealHarmonicAnalysisOfSingleExcitation"],
        "_6110": ["PartHarmonicAnalysisOfSingleExcitation"],
        "_6111": [
            "PartToPartShearCouplingConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_6112": ["PartToPartShearCouplingHalfHarmonicAnalysisOfSingleExcitation"],
        "_6113": ["PartToPartShearCouplingHarmonicAnalysisOfSingleExcitation"],
        "_6114": ["PlanetaryConnectionHarmonicAnalysisOfSingleExcitation"],
        "_6115": ["PlanetaryGearSetHarmonicAnalysisOfSingleExcitation"],
        "_6116": ["PlanetCarrierHarmonicAnalysisOfSingleExcitation"],
        "_6117": ["PointLoadHarmonicAnalysisOfSingleExcitation"],
        "_6118": ["PowerLoadHarmonicAnalysisOfSingleExcitation"],
        "_6119": ["PulleyHarmonicAnalysisOfSingleExcitation"],
        "_6120": ["RingPinsHarmonicAnalysisOfSingleExcitation"],
        "_6121": ["RingPinsToDiscConnectionHarmonicAnalysisOfSingleExcitation"],
        "_6122": ["RollingRingAssemblyHarmonicAnalysisOfSingleExcitation"],
        "_6123": ["RollingRingConnectionHarmonicAnalysisOfSingleExcitation"],
        "_6124": ["RollingRingHarmonicAnalysisOfSingleExcitation"],
        "_6125": ["RootAssemblyHarmonicAnalysisOfSingleExcitation"],
        "_6126": ["ShaftHarmonicAnalysisOfSingleExcitation"],
        "_6127": ["ShaftHubConnectionHarmonicAnalysisOfSingleExcitation"],
        "_6128": [
            "ShaftToMountableComponentConnectionHarmonicAnalysisOfSingleExcitation"
        ],
        "_6129": ["SpecialisedAssemblyHarmonicAnalysisOfSingleExcitation"],
        "_6130": ["SpiralBevelGearHarmonicAnalysisOfSingleExcitation"],
        "_6131": ["SpiralBevelGearMeshHarmonicAnalysisOfSingleExcitation"],
        "_6132": ["SpiralBevelGearSetHarmonicAnalysisOfSingleExcitation"],
        "_6133": ["SpringDamperConnectionHarmonicAnalysisOfSingleExcitation"],
        "_6134": ["SpringDamperHalfHarmonicAnalysisOfSingleExcitation"],
        "_6135": ["SpringDamperHarmonicAnalysisOfSingleExcitation"],
        "_6136": ["StraightBevelDiffGearHarmonicAnalysisOfSingleExcitation"],
        "_6137": ["StraightBevelDiffGearMeshHarmonicAnalysisOfSingleExcitation"],
        "_6138": ["StraightBevelDiffGearSetHarmonicAnalysisOfSingleExcitation"],
        "_6139": ["StraightBevelGearHarmonicAnalysisOfSingleExcitation"],
        "_6140": ["StraightBevelGearMeshHarmonicAnalysisOfSingleExcitation"],
        "_6141": ["StraightBevelGearSetHarmonicAnalysisOfSingleExcitation"],
        "_6142": ["StraightBevelPlanetGearHarmonicAnalysisOfSingleExcitation"],
        "_6143": ["StraightBevelSunGearHarmonicAnalysisOfSingleExcitation"],
        "_6144": ["SynchroniserHalfHarmonicAnalysisOfSingleExcitation"],
        "_6145": ["SynchroniserHarmonicAnalysisOfSingleExcitation"],
        "_6146": ["SynchroniserPartHarmonicAnalysisOfSingleExcitation"],
        "_6147": ["SynchroniserSleeveHarmonicAnalysisOfSingleExcitation"],
        "_6148": ["TorqueConverterConnectionHarmonicAnalysisOfSingleExcitation"],
        "_6149": ["TorqueConverterHarmonicAnalysisOfSingleExcitation"],
        "_6150": ["TorqueConverterPumpHarmonicAnalysisOfSingleExcitation"],
        "_6151": ["TorqueConverterTurbineHarmonicAnalysisOfSingleExcitation"],
        "_6152": ["UnbalancedMassHarmonicAnalysisOfSingleExcitation"],
        "_6153": ["VirtualComponentHarmonicAnalysisOfSingleExcitation"],
        "_6154": ["WormGearHarmonicAnalysisOfSingleExcitation"],
        "_6155": ["WormGearMeshHarmonicAnalysisOfSingleExcitation"],
        "_6156": ["WormGearSetHarmonicAnalysisOfSingleExcitation"],
        "_6157": ["ZerolBevelGearHarmonicAnalysisOfSingleExcitation"],
        "_6158": ["ZerolBevelGearMeshHarmonicAnalysisOfSingleExcitation"],
        "_6159": ["ZerolBevelGearSetHarmonicAnalysisOfSingleExcitation"],
    }

    sys.modules[__name__] = LazyImporter(
        __name__,
        globals()["__file__"],
        import_structure,
    )

__all__ = (
    "AbstractAssemblyHarmonicAnalysisOfSingleExcitation",
    "AbstractShaftHarmonicAnalysisOfSingleExcitation",
    "AbstractShaftOrHousingHarmonicAnalysisOfSingleExcitation",
    "AbstractShaftToMountableComponentConnectionHarmonicAnalysisOfSingleExcitation",
    "AGMAGleasonConicalGearHarmonicAnalysisOfSingleExcitation",
    "AGMAGleasonConicalGearMeshHarmonicAnalysisOfSingleExcitation",
    "AGMAGleasonConicalGearSetHarmonicAnalysisOfSingleExcitation",
    "AssemblyHarmonicAnalysisOfSingleExcitation",
    "BearingHarmonicAnalysisOfSingleExcitation",
    "BeltConnectionHarmonicAnalysisOfSingleExcitation",
    "BeltDriveHarmonicAnalysisOfSingleExcitation",
    "BevelDifferentialGearHarmonicAnalysisOfSingleExcitation",
    "BevelDifferentialGearMeshHarmonicAnalysisOfSingleExcitation",
    "BevelDifferentialGearSetHarmonicAnalysisOfSingleExcitation",
    "BevelDifferentialPlanetGearHarmonicAnalysisOfSingleExcitation",
    "BevelDifferentialSunGearHarmonicAnalysisOfSingleExcitation",
    "BevelGearHarmonicAnalysisOfSingleExcitation",
    "BevelGearMeshHarmonicAnalysisOfSingleExcitation",
    "BevelGearSetHarmonicAnalysisOfSingleExcitation",
    "BoltedJointHarmonicAnalysisOfSingleExcitation",
    "BoltHarmonicAnalysisOfSingleExcitation",
    "ClutchConnectionHarmonicAnalysisOfSingleExcitation",
    "ClutchHalfHarmonicAnalysisOfSingleExcitation",
    "ClutchHarmonicAnalysisOfSingleExcitation",
    "CoaxialConnectionHarmonicAnalysisOfSingleExcitation",
    "ComponentHarmonicAnalysisOfSingleExcitation",
    "ConceptCouplingConnectionHarmonicAnalysisOfSingleExcitation",
    "ConceptCouplingHalfHarmonicAnalysisOfSingleExcitation",
    "ConceptCouplingHarmonicAnalysisOfSingleExcitation",
    "ConceptGearHarmonicAnalysisOfSingleExcitation",
    "ConceptGearMeshHarmonicAnalysisOfSingleExcitation",
    "ConceptGearSetHarmonicAnalysisOfSingleExcitation",
    "ConicalGearHarmonicAnalysisOfSingleExcitation",
    "ConicalGearMeshHarmonicAnalysisOfSingleExcitation",
    "ConicalGearSetHarmonicAnalysisOfSingleExcitation",
    "ConnectionHarmonicAnalysisOfSingleExcitation",
    "ConnectorHarmonicAnalysisOfSingleExcitation",
    "CouplingConnectionHarmonicAnalysisOfSingleExcitation",
    "CouplingHalfHarmonicAnalysisOfSingleExcitation",
    "CouplingHarmonicAnalysisOfSingleExcitation",
    "CVTBeltConnectionHarmonicAnalysisOfSingleExcitation",
    "CVTHarmonicAnalysisOfSingleExcitation",
    "CVTPulleyHarmonicAnalysisOfSingleExcitation",
    "CycloidalAssemblyHarmonicAnalysisOfSingleExcitation",
    "CycloidalDiscCentralBearingConnectionHarmonicAnalysisOfSingleExcitation",
    "CycloidalDiscHarmonicAnalysisOfSingleExcitation",
    "CycloidalDiscPlanetaryBearingConnectionHarmonicAnalysisOfSingleExcitation",
    "CylindricalGearHarmonicAnalysisOfSingleExcitation",
    "CylindricalGearMeshHarmonicAnalysisOfSingleExcitation",
    "CylindricalGearSetHarmonicAnalysisOfSingleExcitation",
    "CylindricalPlanetGearHarmonicAnalysisOfSingleExcitation",
    "DatumHarmonicAnalysisOfSingleExcitation",
    "ExternalCADModelHarmonicAnalysisOfSingleExcitation",
    "FaceGearHarmonicAnalysisOfSingleExcitation",
    "FaceGearMeshHarmonicAnalysisOfSingleExcitation",
    "FaceGearSetHarmonicAnalysisOfSingleExcitation",
    "FEPartHarmonicAnalysisOfSingleExcitation",
    "FlexiblePinAssemblyHarmonicAnalysisOfSingleExcitation",
    "GearHarmonicAnalysisOfSingleExcitation",
    "GearMeshHarmonicAnalysisOfSingleExcitation",
    "GearSetHarmonicAnalysisOfSingleExcitation",
    "GuideDxfModelHarmonicAnalysisOfSingleExcitation",
    "HarmonicAnalysisOfSingleExcitation",
    "HypoidGearHarmonicAnalysisOfSingleExcitation",
    "HypoidGearMeshHarmonicAnalysisOfSingleExcitation",
    "HypoidGearSetHarmonicAnalysisOfSingleExcitation",
    "InterMountableComponentConnectionHarmonicAnalysisOfSingleExcitation",
    "KlingelnbergCycloPalloidConicalGearHarmonicAnalysisOfSingleExcitation",
    "KlingelnbergCycloPalloidConicalGearMeshHarmonicAnalysisOfSingleExcitation",
    "KlingelnbergCycloPalloidConicalGearSetHarmonicAnalysisOfSingleExcitation",
    "KlingelnbergCycloPalloidHypoidGearHarmonicAnalysisOfSingleExcitation",
    "KlingelnbergCycloPalloidHypoidGearMeshHarmonicAnalysisOfSingleExcitation",
    "KlingelnbergCycloPalloidHypoidGearSetHarmonicAnalysisOfSingleExcitation",
    "KlingelnbergCycloPalloidSpiralBevelGearHarmonicAnalysisOfSingleExcitation",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshHarmonicAnalysisOfSingleExcitation",
    "KlingelnbergCycloPalloidSpiralBevelGearSetHarmonicAnalysisOfSingleExcitation",
    "MassDiscHarmonicAnalysisOfSingleExcitation",
    "MeasurementComponentHarmonicAnalysisOfSingleExcitation",
    "ModalAnalysisForHarmonicAnalysis",
    "MountableComponentHarmonicAnalysisOfSingleExcitation",
    "OilSealHarmonicAnalysisOfSingleExcitation",
    "PartHarmonicAnalysisOfSingleExcitation",
    "PartToPartShearCouplingConnectionHarmonicAnalysisOfSingleExcitation",
    "PartToPartShearCouplingHalfHarmonicAnalysisOfSingleExcitation",
    "PartToPartShearCouplingHarmonicAnalysisOfSingleExcitation",
    "PlanetaryConnectionHarmonicAnalysisOfSingleExcitation",
    "PlanetaryGearSetHarmonicAnalysisOfSingleExcitation",
    "PlanetCarrierHarmonicAnalysisOfSingleExcitation",
    "PointLoadHarmonicAnalysisOfSingleExcitation",
    "PowerLoadHarmonicAnalysisOfSingleExcitation",
    "PulleyHarmonicAnalysisOfSingleExcitation",
    "RingPinsHarmonicAnalysisOfSingleExcitation",
    "RingPinsToDiscConnectionHarmonicAnalysisOfSingleExcitation",
    "RollingRingAssemblyHarmonicAnalysisOfSingleExcitation",
    "RollingRingConnectionHarmonicAnalysisOfSingleExcitation",
    "RollingRingHarmonicAnalysisOfSingleExcitation",
    "RootAssemblyHarmonicAnalysisOfSingleExcitation",
    "ShaftHarmonicAnalysisOfSingleExcitation",
    "ShaftHubConnectionHarmonicAnalysisOfSingleExcitation",
    "ShaftToMountableComponentConnectionHarmonicAnalysisOfSingleExcitation",
    "SpecialisedAssemblyHarmonicAnalysisOfSingleExcitation",
    "SpiralBevelGearHarmonicAnalysisOfSingleExcitation",
    "SpiralBevelGearMeshHarmonicAnalysisOfSingleExcitation",
    "SpiralBevelGearSetHarmonicAnalysisOfSingleExcitation",
    "SpringDamperConnectionHarmonicAnalysisOfSingleExcitation",
    "SpringDamperHalfHarmonicAnalysisOfSingleExcitation",
    "SpringDamperHarmonicAnalysisOfSingleExcitation",
    "StraightBevelDiffGearHarmonicAnalysisOfSingleExcitation",
    "StraightBevelDiffGearMeshHarmonicAnalysisOfSingleExcitation",
    "StraightBevelDiffGearSetHarmonicAnalysisOfSingleExcitation",
    "StraightBevelGearHarmonicAnalysisOfSingleExcitation",
    "StraightBevelGearMeshHarmonicAnalysisOfSingleExcitation",
    "StraightBevelGearSetHarmonicAnalysisOfSingleExcitation",
    "StraightBevelPlanetGearHarmonicAnalysisOfSingleExcitation",
    "StraightBevelSunGearHarmonicAnalysisOfSingleExcitation",
    "SynchroniserHalfHarmonicAnalysisOfSingleExcitation",
    "SynchroniserHarmonicAnalysisOfSingleExcitation",
    "SynchroniserPartHarmonicAnalysisOfSingleExcitation",
    "SynchroniserSleeveHarmonicAnalysisOfSingleExcitation",
    "TorqueConverterConnectionHarmonicAnalysisOfSingleExcitation",
    "TorqueConverterHarmonicAnalysisOfSingleExcitation",
    "TorqueConverterPumpHarmonicAnalysisOfSingleExcitation",
    "TorqueConverterTurbineHarmonicAnalysisOfSingleExcitation",
    "UnbalancedMassHarmonicAnalysisOfSingleExcitation",
    "VirtualComponentHarmonicAnalysisOfSingleExcitation",
    "WormGearHarmonicAnalysisOfSingleExcitation",
    "WormGearMeshHarmonicAnalysisOfSingleExcitation",
    "WormGearSetHarmonicAnalysisOfSingleExcitation",
    "ZerolBevelGearHarmonicAnalysisOfSingleExcitation",
    "ZerolBevelGearMeshHarmonicAnalysisOfSingleExcitation",
    "ZerolBevelGearSetHarmonicAnalysisOfSingleExcitation",
)



"""CouplingConnectionMultibodyDynamicsAnalysis"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.mbd_analyses import _5470
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_COUPLING_CONNECTION_MULTIBODY_DYNAMICS_ANALYSIS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.MBDAnalyses",
    "CouplingConnectionMultibodyDynamicsAnalysis",
)

if TYPE_CHECKING:
    from mastapy.system_model.connections_and_sockets.couplings import _2366
    from mastapy.system_model.analyses_and_results.mbd_analyses import (
        _5420,
        _5426,
        _5489,
        _5514,
        _5529,
        _5435,
    )
    from mastapy.system_model.analyses_and_results.analysis_cases import _7563, _7559
    from mastapy.system_model.analyses_and_results import _2670, _2674, _2672


__docformat__ = "restructuredtext en"
__all__ = ("CouplingConnectionMultibodyDynamicsAnalysis",)


Self = TypeVar("Self", bound="CouplingConnectionMultibodyDynamicsAnalysis")


class CouplingConnectionMultibodyDynamicsAnalysis(
    _5470.InterMountableComponentConnectionMultibodyDynamicsAnalysis
):
    """CouplingConnectionMultibodyDynamicsAnalysis

    This is a mastapy class.
    """

    TYPE = _COUPLING_CONNECTION_MULTIBODY_DYNAMICS_ANALYSIS
    _CastSelf = TypeVar(
        "_CastSelf", bound="_Cast_CouplingConnectionMultibodyDynamicsAnalysis"
    )

    class _Cast_CouplingConnectionMultibodyDynamicsAnalysis:
        """Special nested class for casting CouplingConnectionMultibodyDynamicsAnalysis to subclasses."""

        def __init__(
            self: "CouplingConnectionMultibodyDynamicsAnalysis._Cast_CouplingConnectionMultibodyDynamicsAnalysis",
            parent: "CouplingConnectionMultibodyDynamicsAnalysis",
        ):
            self._parent = parent

        @property
        def inter_mountable_component_connection_multibody_dynamics_analysis(
            self: "CouplingConnectionMultibodyDynamicsAnalysis._Cast_CouplingConnectionMultibodyDynamicsAnalysis",
        ) -> "_5470.InterMountableComponentConnectionMultibodyDynamicsAnalysis":
            return self._parent._cast(
                _5470.InterMountableComponentConnectionMultibodyDynamicsAnalysis
            )

        @property
        def connection_multibody_dynamics_analysis(
            self: "CouplingConnectionMultibodyDynamicsAnalysis._Cast_CouplingConnectionMultibodyDynamicsAnalysis",
        ) -> "_5435.ConnectionMultibodyDynamicsAnalysis":
            from mastapy.system_model.analyses_and_results.mbd_analyses import _5435

            return self._parent._cast(_5435.ConnectionMultibodyDynamicsAnalysis)

        @property
        def connection_time_series_load_analysis_case(
            self: "CouplingConnectionMultibodyDynamicsAnalysis._Cast_CouplingConnectionMultibodyDynamicsAnalysis",
        ) -> "_7563.ConnectionTimeSeriesLoadAnalysisCase":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7563

            return self._parent._cast(_7563.ConnectionTimeSeriesLoadAnalysisCase)

        @property
        def connection_analysis_case(
            self: "CouplingConnectionMultibodyDynamicsAnalysis._Cast_CouplingConnectionMultibodyDynamicsAnalysis",
        ) -> "_7559.ConnectionAnalysisCase":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7559

            return self._parent._cast(_7559.ConnectionAnalysisCase)

        @property
        def connection_analysis(
            self: "CouplingConnectionMultibodyDynamicsAnalysis._Cast_CouplingConnectionMultibodyDynamicsAnalysis",
        ) -> "_2670.ConnectionAnalysis":
            from mastapy.system_model.analyses_and_results import _2670

            return self._parent._cast(_2670.ConnectionAnalysis)

        @property
        def design_entity_single_context_analysis(
            self: "CouplingConnectionMultibodyDynamicsAnalysis._Cast_CouplingConnectionMultibodyDynamicsAnalysis",
        ) -> "_2674.DesignEntitySingleContextAnalysis":
            from mastapy.system_model.analyses_and_results import _2674

            return self._parent._cast(_2674.DesignEntitySingleContextAnalysis)

        @property
        def design_entity_analysis(
            self: "CouplingConnectionMultibodyDynamicsAnalysis._Cast_CouplingConnectionMultibodyDynamicsAnalysis",
        ) -> "_2672.DesignEntityAnalysis":
            from mastapy.system_model.analyses_and_results import _2672

            return self._parent._cast(_2672.DesignEntityAnalysis)

        @property
        def clutch_connection_multibody_dynamics_analysis(
            self: "CouplingConnectionMultibodyDynamicsAnalysis._Cast_CouplingConnectionMultibodyDynamicsAnalysis",
        ) -> "_5420.ClutchConnectionMultibodyDynamicsAnalysis":
            from mastapy.system_model.analyses_and_results.mbd_analyses import _5420

            return self._parent._cast(_5420.ClutchConnectionMultibodyDynamicsAnalysis)

        @property
        def concept_coupling_connection_multibody_dynamics_analysis(
            self: "CouplingConnectionMultibodyDynamicsAnalysis._Cast_CouplingConnectionMultibodyDynamicsAnalysis",
        ) -> "_5426.ConceptCouplingConnectionMultibodyDynamicsAnalysis":
            from mastapy.system_model.analyses_and_results.mbd_analyses import _5426

            return self._parent._cast(
                _5426.ConceptCouplingConnectionMultibodyDynamicsAnalysis
            )

        @property
        def part_to_part_shear_coupling_connection_multibody_dynamics_analysis(
            self: "CouplingConnectionMultibodyDynamicsAnalysis._Cast_CouplingConnectionMultibodyDynamicsAnalysis",
        ) -> "_5489.PartToPartShearCouplingConnectionMultibodyDynamicsAnalysis":
            from mastapy.system_model.analyses_and_results.mbd_analyses import _5489

            return self._parent._cast(
                _5489.PartToPartShearCouplingConnectionMultibodyDynamicsAnalysis
            )

        @property
        def spring_damper_connection_multibody_dynamics_analysis(
            self: "CouplingConnectionMultibodyDynamicsAnalysis._Cast_CouplingConnectionMultibodyDynamicsAnalysis",
        ) -> "_5514.SpringDamperConnectionMultibodyDynamicsAnalysis":
            from mastapy.system_model.analyses_and_results.mbd_analyses import _5514

            return self._parent._cast(
                _5514.SpringDamperConnectionMultibodyDynamicsAnalysis
            )

        @property
        def torque_converter_connection_multibody_dynamics_analysis(
            self: "CouplingConnectionMultibodyDynamicsAnalysis._Cast_CouplingConnectionMultibodyDynamicsAnalysis",
        ) -> "_5529.TorqueConverterConnectionMultibodyDynamicsAnalysis":
            from mastapy.system_model.analyses_and_results.mbd_analyses import _5529

            return self._parent._cast(
                _5529.TorqueConverterConnectionMultibodyDynamicsAnalysis
            )

        @property
        def coupling_connection_multibody_dynamics_analysis(
            self: "CouplingConnectionMultibodyDynamicsAnalysis._Cast_CouplingConnectionMultibodyDynamicsAnalysis",
        ) -> "CouplingConnectionMultibodyDynamicsAnalysis":
            return self._parent

        def __getattr__(
            self: "CouplingConnectionMultibodyDynamicsAnalysis._Cast_CouplingConnectionMultibodyDynamicsAnalysis",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(
        self: Self, instance_to_wrap: "CouplingConnectionMultibodyDynamicsAnalysis.TYPE"
    ):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def connection_design(self: Self) -> "_2366.CouplingConnection":
        """mastapy.system_model.connections_and_sockets.couplings.CouplingConnection

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConnectionDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(
        self: Self,
    ) -> "CouplingConnectionMultibodyDynamicsAnalysis._Cast_CouplingConnectionMultibodyDynamicsAnalysis":
        return self._Cast_CouplingConnectionMultibodyDynamicsAnalysis(self)



"""KlingelnbergCycloPalloidConicalGearSingleFlankRating"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy.gears.rating import _367
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_KLINGELNBERG_CYCLO_PALLOID_CONICAL_GEAR_SINGLE_FLANK_RATING = python_net_import(
    "SMT.MastaAPI.Gears.Rating.KlingelnbergConical.KN3030",
    "KlingelnbergCycloPalloidConicalGearSingleFlankRating",
)

if TYPE_CHECKING:
    from mastapy.gears.rating.klingelnberg_conical.kn3030 import _420


__docformat__ = "restructuredtext en"
__all__ = ("KlingelnbergCycloPalloidConicalGearSingleFlankRating",)


Self = TypeVar("Self", bound="KlingelnbergCycloPalloidConicalGearSingleFlankRating")


class KlingelnbergCycloPalloidConicalGearSingleFlankRating(_367.GearSingleFlankRating):
    """KlingelnbergCycloPalloidConicalGearSingleFlankRating

    This is a mastapy class.
    """

    TYPE = _KLINGELNBERG_CYCLO_PALLOID_CONICAL_GEAR_SINGLE_FLANK_RATING
    _CastSelf = TypeVar(
        "_CastSelf", bound="_Cast_KlingelnbergCycloPalloidConicalGearSingleFlankRating"
    )

    class _Cast_KlingelnbergCycloPalloidConicalGearSingleFlankRating:
        """Special nested class for casting KlingelnbergCycloPalloidConicalGearSingleFlankRating to subclasses."""

        def __init__(
            self: "KlingelnbergCycloPalloidConicalGearSingleFlankRating._Cast_KlingelnbergCycloPalloidConicalGearSingleFlankRating",
            parent: "KlingelnbergCycloPalloidConicalGearSingleFlankRating",
        ):
            self._parent = parent

        @property
        def gear_single_flank_rating(
            self: "KlingelnbergCycloPalloidConicalGearSingleFlankRating._Cast_KlingelnbergCycloPalloidConicalGearSingleFlankRating",
        ) -> "_367.GearSingleFlankRating":
            return self._parent._cast(_367.GearSingleFlankRating)

        @property
        def klingelnberg_cyclo_palloid_hypoid_gear_single_flank_rating(
            self: "KlingelnbergCycloPalloidConicalGearSingleFlankRating._Cast_KlingelnbergCycloPalloidConicalGearSingleFlankRating",
        ) -> "_420.KlingelnbergCycloPalloidHypoidGearSingleFlankRating":
            from mastapy.gears.rating.klingelnberg_conical.kn3030 import _420

            return self._parent._cast(
                _420.KlingelnbergCycloPalloidHypoidGearSingleFlankRating
            )

        @property
        def klingelnberg_cyclo_palloid_conical_gear_single_flank_rating(
            self: "KlingelnbergCycloPalloidConicalGearSingleFlankRating._Cast_KlingelnbergCycloPalloidConicalGearSingleFlankRating",
        ) -> "KlingelnbergCycloPalloidConicalGearSingleFlankRating":
            return self._parent

        def __getattr__(
            self: "KlingelnbergCycloPalloidConicalGearSingleFlankRating._Cast_KlingelnbergCycloPalloidConicalGearSingleFlankRating",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(
        self: Self,
        instance_to_wrap: "KlingelnbergCycloPalloidConicalGearSingleFlankRating.TYPE",
    ):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def allowable_bending_stress_number(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AllowableBendingStressNumber

        if temp is None:
            return 0.0

        return temp

    @property
    def allowable_contact_stress_number(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AllowableContactStressNumber

        if temp is None:
            return 0.0

        return temp

    @property
    def bending_stress(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.BendingStress

        if temp is None:
            return 0.0

        return temp

    @property
    def bending_stress_limit(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.BendingStressLimit

        if temp is None:
            return 0.0

        return temp

    @property
    def bending_stress_safety_factor(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.BendingStressSafetyFactor

        if temp is None:
            return 0.0

        return temp

    @property
    def flank_roughness(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FlankRoughness

        if temp is None:
            return 0.0

        return temp

    @property
    def mean_pitch_diameter(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MeanPitchDiameter

        if temp is None:
            return 0.0

        return temp

    @property
    def rated_tangential_force(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RatedTangentialForce

        if temp is None:
            return 0.0

        return temp

    @property
    def rated_torque(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RatedTorque

        if temp is None:
            return 0.0

        return temp

    @property
    def relative_sensitivity_factor(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RelativeSensitivityFactor

        if temp is None:
            return 0.0

        return temp

    @property
    def relative_surface_factor(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RelativeSurfaceFactor

        if temp is None:
            return 0.0

        return temp

    @property
    def size_factor(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SizeFactor

        if temp is None:
            return 0.0

        return temp

    @property
    def stress_correction_factor(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.StressCorrectionFactor

        if temp is None:
            return 0.0

        return temp

    @property
    def tangential_speed(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TangentialSpeed

        if temp is None:
            return 0.0

        return temp

    @property
    def tooth_form_factor(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ToothFormFactor

        if temp is None:
            return 0.0

        return temp

    @property
    def cast_to(
        self: Self,
    ) -> "KlingelnbergCycloPalloidConicalGearSingleFlankRating._Cast_KlingelnbergCycloPalloidConicalGearSingleFlankRating":
        return self._Cast_KlingelnbergCycloPalloidConicalGearSingleFlankRating(self)



"""BevelGearSetLoadCase"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.static_loads import _6837
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_BEVEL_GEAR_SET_LOAD_CASE = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.StaticLoads", "BevelGearSetLoadCase"
)

if TYPE_CHECKING:
    from mastapy.system_model.part_model.gears import _2540
    from mastapy.system_model.analyses_and_results.static_loads import (
        _6846,
        _6977,
        _6983,
        _6986,
        _7009,
        _6870,
        _6917,
        _6974,
        _6828,
        _6950,
    )
    from mastapy.system_model.analyses_and_results import _2678, _2674, _2672


__docformat__ = "restructuredtext en"
__all__ = ("BevelGearSetLoadCase",)


Self = TypeVar("Self", bound="BevelGearSetLoadCase")


class BevelGearSetLoadCase(_6837.AGMAGleasonConicalGearSetLoadCase):
    """BevelGearSetLoadCase

    This is a mastapy class.
    """

    TYPE = _BEVEL_GEAR_SET_LOAD_CASE
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_BevelGearSetLoadCase")

    class _Cast_BevelGearSetLoadCase:
        """Special nested class for casting BevelGearSetLoadCase to subclasses."""

        def __init__(
            self: "BevelGearSetLoadCase._Cast_BevelGearSetLoadCase",
            parent: "BevelGearSetLoadCase",
        ):
            self._parent = parent

        @property
        def agma_gleason_conical_gear_set_load_case(
            self: "BevelGearSetLoadCase._Cast_BevelGearSetLoadCase",
        ) -> "_6837.AGMAGleasonConicalGearSetLoadCase":
            return self._parent._cast(_6837.AGMAGleasonConicalGearSetLoadCase)

        @property
        def conical_gear_set_load_case(
            self: "BevelGearSetLoadCase._Cast_BevelGearSetLoadCase",
        ) -> "_6870.ConicalGearSetLoadCase":
            from mastapy.system_model.analyses_and_results.static_loads import _6870

            return self._parent._cast(_6870.ConicalGearSetLoadCase)

        @property
        def gear_set_load_case(
            self: "BevelGearSetLoadCase._Cast_BevelGearSetLoadCase",
        ) -> "_6917.GearSetLoadCase":
            from mastapy.system_model.analyses_and_results.static_loads import _6917

            return self._parent._cast(_6917.GearSetLoadCase)

        @property
        def specialised_assembly_load_case(
            self: "BevelGearSetLoadCase._Cast_BevelGearSetLoadCase",
        ) -> "_6974.SpecialisedAssemblyLoadCase":
            from mastapy.system_model.analyses_and_results.static_loads import _6974

            return self._parent._cast(_6974.SpecialisedAssemblyLoadCase)

        @property
        def abstract_assembly_load_case(
            self: "BevelGearSetLoadCase._Cast_BevelGearSetLoadCase",
        ) -> "_6828.AbstractAssemblyLoadCase":
            from mastapy.system_model.analyses_and_results.static_loads import _6828

            return self._parent._cast(_6828.AbstractAssemblyLoadCase)

        @property
        def part_load_case(
            self: "BevelGearSetLoadCase._Cast_BevelGearSetLoadCase",
        ) -> "_6950.PartLoadCase":
            from mastapy.system_model.analyses_and_results.static_loads import _6950

            return self._parent._cast(_6950.PartLoadCase)

        @property
        def part_analysis(
            self: "BevelGearSetLoadCase._Cast_BevelGearSetLoadCase",
        ) -> "_2678.PartAnalysis":
            from mastapy.system_model.analyses_and_results import _2678

            return self._parent._cast(_2678.PartAnalysis)

        @property
        def design_entity_single_context_analysis(
            self: "BevelGearSetLoadCase._Cast_BevelGearSetLoadCase",
        ) -> "_2674.DesignEntitySingleContextAnalysis":
            from mastapy.system_model.analyses_and_results import _2674

            return self._parent._cast(_2674.DesignEntitySingleContextAnalysis)

        @property
        def design_entity_analysis(
            self: "BevelGearSetLoadCase._Cast_BevelGearSetLoadCase",
        ) -> "_2672.DesignEntityAnalysis":
            from mastapy.system_model.analyses_and_results import _2672

            return self._parent._cast(_2672.DesignEntityAnalysis)

        @property
        def bevel_differential_gear_set_load_case(
            self: "BevelGearSetLoadCase._Cast_BevelGearSetLoadCase",
        ) -> "_6846.BevelDifferentialGearSetLoadCase":
            from mastapy.system_model.analyses_and_results.static_loads import _6846

            return self._parent._cast(_6846.BevelDifferentialGearSetLoadCase)

        @property
        def spiral_bevel_gear_set_load_case(
            self: "BevelGearSetLoadCase._Cast_BevelGearSetLoadCase",
        ) -> "_6977.SpiralBevelGearSetLoadCase":
            from mastapy.system_model.analyses_and_results.static_loads import _6977

            return self._parent._cast(_6977.SpiralBevelGearSetLoadCase)

        @property
        def straight_bevel_diff_gear_set_load_case(
            self: "BevelGearSetLoadCase._Cast_BevelGearSetLoadCase",
        ) -> "_6983.StraightBevelDiffGearSetLoadCase":
            from mastapy.system_model.analyses_and_results.static_loads import _6983

            return self._parent._cast(_6983.StraightBevelDiffGearSetLoadCase)

        @property
        def straight_bevel_gear_set_load_case(
            self: "BevelGearSetLoadCase._Cast_BevelGearSetLoadCase",
        ) -> "_6986.StraightBevelGearSetLoadCase":
            from mastapy.system_model.analyses_and_results.static_loads import _6986

            return self._parent._cast(_6986.StraightBevelGearSetLoadCase)

        @property
        def zerol_bevel_gear_set_load_case(
            self: "BevelGearSetLoadCase._Cast_BevelGearSetLoadCase",
        ) -> "_7009.ZerolBevelGearSetLoadCase":
            from mastapy.system_model.analyses_and_results.static_loads import _7009

            return self._parent._cast(_7009.ZerolBevelGearSetLoadCase)

        @property
        def bevel_gear_set_load_case(
            self: "BevelGearSetLoadCase._Cast_BevelGearSetLoadCase",
        ) -> "BevelGearSetLoadCase":
            return self._parent

        def __getattr__(
            self: "BevelGearSetLoadCase._Cast_BevelGearSetLoadCase", name: str
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "BevelGearSetLoadCase.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def assembly_design(self: Self) -> "_2540.BevelGearSet":
        """mastapy.system_model.part_model.gears.BevelGearSet

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AssemblyDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: Self) -> "BevelGearSetLoadCase._Cast_BevelGearSetLoadCase":
        return self._Cast_BevelGearSetLoadCase(self)
